@@ -12,10 +12,10 @@
 local tables = {}
 
 tables.highways = osm2pgsql.define_way_table('highways', {
-    { column = 'tags',     type = 'jsonb' },
+    { column = 'tags', type = 'jsonb' },
     { column = 'rel_refs', type = 'text' }, -- for the refs from the relations
-    { column = 'rel_ids',  sql_type = 'int8[]' }, -- array with integers (for relation IDs)
-    { column = 'geom',     type = 'linestring', not_null = true },
+    { column = 'rel_ids', sql_type = 'int8[]' }, -- array with integers (for relation IDs)
+    { column = 'geom', type = 'linestring', not_null = true },
 })
 
 -- Tables don't have to have a geometry column
@@ -31,23 +31,12 @@ tables.routes = osm2pgsql.define_relation_table('routes', {
 -- it can be called any number of times and will lead to the same result.
 local w2r = {}
 
-local function clean_tags(tags)
-    tags.odbl = nil
-    tags.created_by = nil
-    tags.source = nil
-    tags['source:ref'] = nil
-
-    return next(tags) == nil
-end
-
 function osm2pgsql.process_way(object)
     -- We are only interested in highways
     if not object.tags.highway then
         return
     end
 
-    clean_tags(object.tags)
-
     -- Data we will store in the "highways" table always has the tags from
     -- the way
     local row = {
