@@ -10,21 +10,18 @@
 #include "command-line-parser.hpp"
 
 #include "command-line-app.hpp"
-#include "format.hpp"
 #include "logging.hpp"
 #include "options.hpp"
 #include "pgsql.hpp"
+#include "projection.hpp"
 #include "reprojection.hpp"
 #include "util.hpp"
 #include "version.hpp"
 
 #include <osmium/util/string.hpp>
-#include <osmium/version.hpp>
 
 #include <CLI/CLI.hpp>
 
-#include <lua.hpp>
-
 #include <algorithm>
 #include <cmath>
 #include <cstdio>
@@ -228,7 +225,8 @@ void check_options(options_t *options)
     }
 }
 
-void check_options_expire(options_t *options) {
+void check_options_expire(options_t *options)
+{
     // Zoom level 31 is the technical limit because we use 32-bit integers for
     // the x and y index of a tile ID.
     if (options->expire_tiles_zoom_min > 31) {
@@ -244,7 +242,7 @@ void check_options_expire(options_t *options) {
     }
 
     if (options->expire_tiles_zoom != 0 &&
-        options->projection->target_srs() != 3857) {
+        options->projection->target_srs() != PROJ_SPHERE_MERC) {
         log_warn("Expire has been enabled (with -e or --expire-tiles) but "
                  "target SRS is not Mercator (EPSG:3857). Expire disabled!");
         options->expire_tiles_zoom = 0;
@@ -253,20 +251,6 @@ void check_options_expire(options_t *options) {
 
 } // anonymous namespace
 
-void print_version()
-{
-    fmt::print(stderr, "osm2pgsql version {}\n", get_osm2pgsql_version());
-    fmt::print(stderr, "Build: {}\n", get_build_type());
-    fmt::print(stderr, "Compiled using the following library versions:\n");
-    fmt::print(stderr, "Libosmium {}\n", LIBOSMIUM_VERSION_STRING);
-    fmt::print(stderr, "Proj {}\n", get_proj_version());
-#ifdef HAVE_LUAJIT
-    fmt::print(stderr, "{} ({})\n", LUA_RELEASE, LUAJIT_VERSION);
-#else
-    fmt::print(stderr, "{}\n", LUA_RELEASE);
-#endif
-}
-
 // NOLINTNEXTLINE(cppcoreguidelines-avoid-c-arrays,hicpp-avoid-c-arrays,modernize-avoid-c-arrays)
 options_t parse_command_line(int argc, char *argv[])
 {
@@ -281,6 +265,9 @@ options_t parse_command_line(int argc, char *argv[])
 
     command_line_app_t app{"osm2pgsql -- Import OpenStreetMap data into a "
                            "PostgreSQL/PostGIS database\n"};
+    app.init_database_options();
+    app.init_logging_options(true, true);
+
     app.get_formatter()->column_width(38);
 
     app.add_option("OSMFILE", options.input_files)
@@ -408,7 +395,8 @@ options_t parse_command_line(int argc, char *argv[])
     app.add_flag_function("-l,--latlong",
                           [&](int64_t) {
                               options.projection =
-                                  reprojection::create_projection(PROJ_LATLONG);
+                                  reprojection_t::create_projection(
+                                      PROJ_LATLONG);
                           })
         ->description("Store data in degrees of latitude & longitude (WGS84).")
         ->group("Pgsql output options");
@@ -417,7 +405,7 @@ options_t parse_command_line(int argc, char *argv[])
     app.add_flag_function("-m,--merc",
                           [&](int64_t) {
                               options.projection =
-                                  reprojection::create_projection(
+                                  reprojection_t::create_projection(
                                       PROJ_SPHERE_MERC);
                           })
         ->description("Store data in Web Mercator [EPSG 3857]. This is the "
@@ -441,7 +429,7 @@ options_t parse_command_line(int argc, char *argv[])
 #ifdef HAVE_GENERIC_PROJ
                                  [&](int arg) {
                                      options.projection =
-                                         reprojection::create_projection(arg);
+                                         reprojection_t::create_projection(arg);
 #else
            [&](int) {
                throw std::runtime_error{
@@ -681,7 +669,8 @@ options_t parse_command_line(int argc, char *argv[])
     }
 
     if (!options.projection) {
-        options.projection = reprojection::create_projection(PROJ_SPHERE_MERC);
+        options.projection =
+            reprojection_t::create_projection(PROJ_SPHERE_MERC);
     }
 
     check_options_expire(&options);
