@@ -31,7 +31,7 @@ void db_deleter_by_id_t::delete_rows(std::string const &table,
     fmt::format_to(std::back_inserter(sql),
                    FMT_STRING("DELETE FROM {} WHERE {} IN ("), table, column);
 
-    for (auto id : m_deletables) {
+    for (auto const id : m_deletables) {
         format_to(std::back_inserter(sql), FMT_STRING("{},"), id);
     }
     sql[sql.size() - 1] = ')';
@@ -100,7 +100,7 @@ void db_copy_thread_t::send_command(db_cmd_t &&buffer)
 
     std::unique_lock<std::mutex> lock{m_shared.queue_mutex};
     m_shared.queue_full_cond.wait(lock, [&] {
-        return m_shared.worker_queue.size() < db_cmd_copy_t::Max_buffers;
+        return m_shared.worker_queue.size() < db_cmd_copy_t::MAX_BUFFERS;
     });
 
     m_shared.worker_queue.push_back(std::move(buffer));
@@ -221,7 +221,7 @@ void db_copy_thread_t::thread_t::start_copy(
     }
 
     sql.push_back('\0');
-    m_db_connection.copy_start(sql.data());
+    m_db_connection.copy_start(to_string(sql));
 
     m_inflight = target;
 }
