@@ -7,14 +7,6 @@
  * For a full list of authors see the git log.
  */
 
-/*
- * Dirty tile list generation
- *
- * Please refer to the OpenPisteMap expire_tiles.py script for a demonstration
- * of how to make use of the output:
- * http://subversion.nexusuk.org/projects/openpistemap/trunk/scripts/expire_tiles.py
- */
-
 #include <algorithm>
 #include <cerrno>
 #include <cmath>
@@ -28,18 +20,19 @@
 #include "format.hpp"
 #include "geom-functions.hpp"
 #include "options.hpp"
+#include "projection.hpp"
 #include "reprojection.hpp"
 #include "table.hpp"
 #include "tile.hpp"
 #include "wkb.hpp"
 
-expire_tiles::expire_tiles(uint32_t max_zoom,
-                           std::shared_ptr<reprojection> projection)
+expire_tiles_t::expire_tiles_t(uint32_t max_zoom,
+                               std::shared_ptr<reprojection_t> projection)
 : m_projection(std::move(projection)), m_maxzoom(max_zoom),
   m_map_width(static_cast<int>(1U << m_maxzoom))
 {}
 
-void expire_tiles::expire_tile(uint32_t x, uint32_t y)
+void expire_tiles_t::expire_tile(uint32_t x, uint32_t y)
 {
     // Only try to insert to tile into the set if the last inserted tile
     // is different from this tile.
@@ -50,7 +43,7 @@ void expire_tiles::expire_tile(uint32_t x, uint32_t y)
     }
 }
 
-uint32_t expire_tiles::normalise_tile_x_coord(int x) const
+uint32_t expire_tiles_t::normalise_tile_x_coord(int x) const
 {
     x %= m_map_width;
     if (x < 0) {
@@ -59,37 +52,37 @@ uint32_t expire_tiles::normalise_tile_x_coord(int x) const
     return static_cast<uint32_t>(x);
 }
 
-geom::point_t expire_tiles::coords_to_tile(geom::point_t const &point)
+geom::point_t expire_tiles_t::coords_to_tile(geom::point_t const &point)
 {
     auto const c = m_projection->target_to_tile(point);
 
-    return {m_map_width * (0.5 + c.x() / tile_t::earth_circumference),
-            m_map_width * (0.5 - c.y() / tile_t::earth_circumference)};
+    return {m_map_width * (0.5 + c.x() / tile_t::EARTH_CIRCUMFERENCE),
+            m_map_width * (0.5 - c.y() / tile_t::EARTH_CIRCUMFERENCE)};
 }
 
-void expire_tiles::from_point_list(geom::point_list_t const &list,
-                                   expire_config_t const &expire_config)
+void expire_tiles_t::from_point_list(geom::point_list_t const &list,
+                                     expire_config_t const &expire_config)
 {
     for_each_segment(list, [&](geom::point_t const &a, geom::point_t const &b) {
         from_line_segment(a, b, expire_config);
     });
 }
 
-void expire_tiles::from_geometry(geom::point_t const &geom,
-                                 expire_config_t const &expire_config)
+void expire_tiles_t::from_geometry(geom::point_t const &geom,
+                                   expire_config_t const &expire_config)
 {
     geom::box_t const box = geom::envelope(geom);
     from_bbox(box, expire_config);
 }
 
-void expire_tiles::from_geometry(geom::linestring_t const &geom,
-                                 expire_config_t const &expire_config)
+void expire_tiles_t::from_geometry(geom::linestring_t const &geom,
+                                   expire_config_t const &expire_config)
 {
     from_point_list(geom, expire_config);
 }
 
-void expire_tiles::from_polygon_boundary(geom::polygon_t const &geom,
-                                         expire_config_t const &expire_config)
+void expire_tiles_t::from_polygon_boundary(geom::polygon_t const &geom,
+                                           expire_config_t const &expire_config)
 {
     from_point_list(geom.outer(), expire_config);
     for (auto const &inner : geom.inners()) {
@@ -97,8 +90,8 @@ void expire_tiles::from_polygon_boundary(geom::polygon_t const &geom,
     }
 }
 
-void expire_tiles::from_geometry(geom::polygon_t const &geom,
-                                 expire_config_t const &expire_config)
+void expire_tiles_t::from_geometry(geom::polygon_t const &geom,
+                                   expire_config_t const &expire_config)
 {
     if (expire_config.mode == expire_mode::boundary_only) {
         from_polygon_boundary(geom, expire_config);
@@ -112,16 +105,16 @@ void expire_tiles::from_geometry(geom::polygon_t const &geom,
     }
 }
 
-void expire_tiles::from_polygon_boundary(geom::multipolygon_t const &geom,
-                                         expire_config_t const &expire_config)
+void expire_tiles_t::from_polygon_boundary(geom::multipolygon_t const &geom,
+                                           expire_config_t const &expire_config)
 {
     for (auto const &sgeom : geom) {
         from_polygon_boundary(sgeom, expire_config);
     }
 }
 
-void expire_tiles::from_geometry(geom::multipolygon_t const &geom,
-                                 expire_config_t const &expire_config)
+void expire_tiles_t::from_geometry(geom::multipolygon_t const &geom,
+                                   expire_config_t const &expire_config)
 {
     if (expire_config.mode == expire_mode::boundary_only) {
         from_polygon_boundary(geom, expire_config);
@@ -137,16 +130,16 @@ void expire_tiles::from_geometry(geom::multipolygon_t const &geom,
 
 // False positive: Apparently clang-tidy can not see through the visit()
 // NOLINTNEXTLINE(readability-convert-member-functions-to-static)
-void expire_tiles::from_geometry(geom::geometry_t const &geom,
-                                 expire_config_t const &expire_config)
+void expire_tiles_t::from_geometry(geom::geometry_t const &geom,
+                                   expire_config_t const &expire_config)
 {
     geom.visit([&](auto const &g) { from_geometry(g, expire_config); });
 }
 
-void expire_tiles::from_geometry_if_3857(geom::geometry_t const &geom,
-                                         expire_config_t const &expire_config)
+void expire_tiles_t::from_geometry_if_3857(geom::geometry_t const &geom,
+                                           expire_config_t const &expire_config)
 {
-    if (geom.srid() == 3857) {
+    if (geom.srid() == PROJ_SPHERE_MERC) {
         from_geometry(geom, expire_config);
     }
 }
@@ -154,9 +147,9 @@ void expire_tiles::from_geometry_if_3857(geom::geometry_t const &geom,
 /*
  * Expire tiles that a line crosses
  */
-void expire_tiles::from_line_segment(geom::point_t const &a,
-                                     geom::point_t const &b,
-                                     expire_config_t const &expire_config)
+void expire_tiles_t::from_line_segment(geom::point_t const &a,
+                                       geom::point_t const &b,
+                                       expire_config_t const &expire_config)
 {
     auto tilec_a = coords_to_tile(a);
     auto tilec_b = coords_to_tile(b);
@@ -176,20 +169,19 @@ void expire_tiles::from_line_segment(geom::point_t const &a,
     }
 
     double const y_len = tilec_b.y() - tilec_a.y();
-    double const hyp_len = std::sqrt(x_len * x_len + y_len * y_len); /* Pythagoras */
+    double const hyp_len =
+        std::sqrt(x_len * x_len + y_len * y_len); /* Pythagoras */
     double const x_step = x_len / hyp_len;
     double const y_step = y_len / hyp_len;
 
-    for (double step = 0; step <= hyp_len; step += 0.4) {
-        /* Interpolate points 1 tile width apart */
-        double next_step = step + 0.4;
-        if (next_step > hyp_len) {
-            next_step = hyp_len;
-        }
-        double x1 = tilec_a.x() + ((double)step * x_step);
-        double y1 = tilec_a.y() + ((double)step * y_step);
-        double x2 = tilec_a.x() + ((double)next_step * x_step);
-        double y2 = tilec_a.y() + ((double)next_step * y_step);
+    for (int i = 0; i <= hyp_len / 0.4; ++i) {
+        double const step = i * 0.4;
+        double const next_step = std::min(hyp_len, (i + 1) * 0.4);
+
+        double const x1 = tilec_a.x() + (step * x_step);
+        double y1 = tilec_a.y() + (step * y_step);
+        double const x2 = tilec_a.x() + (next_step * x_step);
+        double y2 = tilec_a.y() + (next_step * y_step);
 
         /* The line (x1,y1),(x2,y2) is up to 1 tile width long
            x1 will always be <= x2
@@ -199,11 +191,11 @@ void expire_tiles::from_line_segment(geom::point_t const &a,
         if (y1 > y2) {
             std::swap(y1, y2);
         }
-        for (int x = x1 - expire_config.buffer; x <= x2 + expire_config.buffer;
-             ++x) {
+        for (int x = static_cast<int>(x1 - expire_config.buffer);
+             x <= static_cast<int>(x2 + expire_config.buffer); ++x) {
             uint32_t const norm_x = normalise_tile_x_coord(x);
-            for (int y = y1 - expire_config.buffer;
-                 y <= y2 + expire_config.buffer; ++y) {
+            for (int y = static_cast<int>(y1 - expire_config.buffer);
+                 y <= static_cast<int>(y2 + expire_config.buffer); ++y) {
                 if (y >= 0) {
                     expire_tile(norm_x, static_cast<uint32_t>(y));
                 }
@@ -215,8 +207,8 @@ void expire_tiles::from_line_segment(geom::point_t const &a,
 /*
  * Expire tiles within a bounding box
  */
-int expire_tiles::from_bbox(geom::box_t const &box,
-                            expire_config_t const &expire_config)
+int expire_tiles_t::from_bbox(geom::box_t const &box,
+                              expire_config_t const &expire_config)
 {
     if (!enabled()) {
         return 0;
@@ -224,14 +216,14 @@ int expire_tiles::from_bbox(geom::box_t const &box,
 
     double const width = box.width();
     double const height = box.height();
-    if (width > tile_t::half_earth_circumference + 1) {
+    if (width > tile_t::HALF_EARTH_CIRCUMFERENCE + 1) {
         /* Over half the planet's width within the bounding box - assume the
            box crosses the international date line and split it into two boxes */
-        int ret = from_bbox({-tile_t::half_earth_circumference, box.min_y(),
+        int ret = from_bbox({-tile_t::HALF_EARTH_CIRCUMFERENCE, box.min_y(),
                              box.min_x(), box.max_y()},
                             expire_config);
         ret += from_bbox({box.max_x(), box.min_y(),
-                          tile_t::half_earth_circumference, box.max_y()},
+                          tile_t::HALF_EARTH_CIRCUMFERENCE, box.max_y()},
                          expire_config);
         return ret;
     }
@@ -265,17 +257,17 @@ int expire_tiles::from_bbox(geom::box_t const &box,
     return 0;
 }
 
-quadkey_list_t expire_tiles::get_tiles()
+quadkey_list_t expire_tiles_t::get_tiles()
 {
     quadkey_list_t tiles;
     tiles.reserve(m_dirty_tiles.size());
-    tiles.assign(m_dirty_tiles.begin(), m_dirty_tiles.end());
+    tiles.assign(m_dirty_tiles.cbegin(), m_dirty_tiles.cend());
     std::sort(tiles.begin(), tiles.end());
     m_dirty_tiles.clear();
     return tiles;
 }
 
-void expire_tiles::merge_and_destroy(expire_tiles *other)
+void expire_tiles_t::merge_and_destroy(expire_tiles_t *other)
 {
     if (m_map_width != other->m_map_width) {
         throw fmt_error("Unable to merge tile expiry sets when "
@@ -287,13 +279,13 @@ void expire_tiles::merge_and_destroy(expire_tiles *other)
         using std::swap;
         swap(m_dirty_tiles, other->m_dirty_tiles);
     } else {
-        m_dirty_tiles.insert(other->m_dirty_tiles.begin(),
-                             other->m_dirty_tiles.end());
+        m_dirty_tiles.insert(other->m_dirty_tiles.cbegin(),
+                             other->m_dirty_tiles.cend());
         other->m_dirty_tiles.clear();
     }
 }
 
-int expire_from_result(expire_tiles *expire, pg_result_t const &result,
+int expire_from_result(expire_tiles_t *expire, pg_result_t const &result,
                        expire_config_t const &expire_config)
 {
     auto const num_tuples = result.num_tuples();
