@@ -12,10 +12,11 @@
 #include "geom-functions.hpp"
 #include "geom-pole-of-inaccessibility.hpp"
 #include "lua-utils.hpp"
+#include "projection.hpp"
 
 #include <lua.hpp>
 
-static char const *const osm2pgsql_geometry_class = "osm2pgsql.Geometry";
+static char const *const OSM2PGSQL_GEOMETRY_CLASS = "osm2pgsql.Geometry";
 
 geom::geometry_t *create_lua_geometry_object(lua_State *lua_state)
 {
@@ -23,7 +24,7 @@ geom::geometry_t *create_lua_geometry_object(lua_State *lua_state)
     new (ptr) geom::geometry_t{};
 
     // Set the metatable of this object
-    luaL_getmetatable(lua_state, osm2pgsql_geometry_class);
+    luaL_getmetatable(lua_state, OSM2PGSQL_GEOMETRY_CLASS);
     lua_setmetatable(lua_state, -2);
 
     return static_cast<geom::geometry_t *>(ptr);
@@ -31,11 +32,13 @@ geom::geometry_t *create_lua_geometry_object(lua_State *lua_state)
 
 geom::geometry_t *unpack_geometry(lua_State *lua_state, int n) noexcept
 {
-    void *user_data = luaL_checkudata(lua_state, n, osm2pgsql_geometry_class);
+    void *user_data = luaL_checkudata(lua_state, n, OSM2PGSQL_GEOMETRY_CLASS);
     luaL_argcheck(lua_state, user_data != nullptr, n, "'Geometry' expected");
     return static_cast<geom::geometry_t *>(user_data);
 }
 
+namespace {
+
 /**
  * This function is called by Lua garbage collection when a geometry object
  * needs cleaning up. It calls the destructor of the C++ object. After that
@@ -51,8 +54,6 @@ int geom_gc(lua_State *lua_state) noexcept
     return 0;
 }
 
-namespace {
-
 // The following functions are called when their counterparts in Lua are
 // called on geometry objects.
 
@@ -73,7 +74,7 @@ int geom_spherical_area(lua_State *lua_state)
 {
     auto const *const input_geometry = unpack_geometry(lua_state);
 
-    if (input_geometry->srid() != 4326) {
+    if (input_geometry->srid() != PROJ_LATLONG) {
         throw std::runtime_error{"Can only calculate spherical area for "
                                  "geometries in WGS84 (4326) coordinates."};
     }
@@ -282,7 +283,7 @@ int geom_transform(lua_State *lua_state)
     auto const srid = static_cast<int>(luaL_checkinteger(lua_state, 2));
 
     try {
-        if (input_geometry->srid() != 4326) {
+        if (input_geometry->srid() != PROJ_LATLONG) {
             throw std::runtime_error{
                 "Can not transform already transformed geometry."};
         }
@@ -299,37 +300,25 @@ int geom_transform(lua_State *lua_state)
 
 void init_geometry_class(lua_State *lua_state)
 {
-    lua_getglobal(lua_state, "osm2pgsql");
-    if (luaL_newmetatable(lua_state, osm2pgsql_geometry_class) != 1) {
-        throw std::runtime_error{"Internal error: Lua newmetatable failed."};
-    }
-    lua_pushvalue(lua_state, -1); // Copy of new metatable
-
-    // Add metatable as osm2pgsql.Geometry so we can access it from Lua
-    lua_setfield(lua_state, -3, "Geometry");
-
-    luaX_add_table_func(lua_state, "__gc", geom_gc);
-    luaX_add_table_func(lua_state, "__len", geom_num_geometries);
-    luaX_add_table_func(lua_state, "__tostring", geom_tostring);
-    lua_pushvalue(lua_state, -1);
-    lua_setfield(lua_state, -2, "__index");
-    luaX_add_table_func(lua_state, "area", geom_area);
-    luaX_add_table_func(lua_state, "length", geom_length);
-    luaX_add_table_func(lua_state, "centroid", geom_centroid);
-    luaX_add_table_func(lua_state, "get_bbox", geom_get_bbox);
-    luaX_add_table_func(lua_state, "geometry_n", geom_geometry_n);
-    luaX_add_table_func(lua_state, "geometry_type", geom_geometry_type);
-    luaX_add_table_func(lua_state, "is_null", geom_is_null);
-    luaX_add_table_func(lua_state, "line_merge", geom_line_merge);
-    luaX_add_table_func(lua_state, "reverse", geom_reverse);
-    luaX_add_table_func(lua_state, "num_geometries", geom_num_geometries);
-    luaX_add_table_func(lua_state, "pole_of_inaccessibility",
-                        geom_pole_of_inaccessibility);
-    luaX_add_table_func(lua_state, "segmentize", geom_segmentize);
-    luaX_add_table_func(lua_state, "simplify", geom_simplify);
-    luaX_add_table_func(lua_state, "spherical_area", geom_spherical_area);
-    luaX_add_table_func(lua_state, "srid", geom_srid);
-    luaX_add_table_func(lua_state, "transform", geom_transform);
-
-    lua_pop(lua_state, 2); // __index, global osmp2gsql
+    luaX_set_up_metatable(
+        lua_state, "Geometry", OSM2PGSQL_GEOMETRY_CLASS,
+        {{"__gc", geom_gc},
+         {"__len", geom_num_geometries},
+         {"__tostring", geom_tostring},
+         {"area", geom_area},
+         {"length", geom_length},
+         {"centroid", geom_centroid},
+         {"get_bbox", geom_get_bbox},
+         {"geometry_n", geom_geometry_n},
+         {"geometry_type", geom_geometry_type},
+         {"is_null", geom_is_null},
+         {"line_merge", geom_line_merge},
+         {"reverse", geom_reverse},
+         {"num_geometries", geom_num_geometries},
+         {"pole_of_inaccessibility", geom_pole_of_inaccessibility},
+         {"segmentize", geom_segmentize},
+         {"simplify", geom_simplify},
+         {"spherical_area", geom_spherical_area},
+         {"srid", geom_srid},
+         {"transform", geom_transform}});
 }
