@@ -14,7 +14,10 @@
 #include "flex-lua-index.hpp"
 #include "flex-table.hpp"
 #include "lua-utils.hpp"
+#include "output-flex.hpp"
 #include "pgsql-capabilities.hpp"
+#include "projection.hpp"
+#include "util.hpp"
 
 #include <lua.hpp>
 
@@ -23,10 +26,9 @@ namespace {
 void check_tablespace(std::string const &tablespace)
 {
     if (!has_tablespace(tablespace)) {
-        throw fmt_error(
-            "Tablespace '{0}' not available."
-            " Use 'CREATE TABLESPACE \"{0}\" ...;' to create it.",
-            tablespace);
+        throw fmt_error("Tablespace '{0}' not available."
+                        " Use 'CREATE TABLESPACE \"{0}\" ...;' to create it.",
+                        tablespace);
     }
 }
 
@@ -193,7 +195,7 @@ std::size_t idx_from_userdata(lua_State *lua_state, int idx,
         throw std::runtime_error{"Expire output must be of type ExpireOutput."};
     }
 
-    luaL_getmetatable(lua_state, osm2pgsql_expire_output_name);
+    luaL_getmetatable(lua_state, OSM2PGSQL_EXPIRE_OUTPUT_CLASS);
     if (!lua_rawequal(lua_state, -1, -2)) {
         throw std::runtime_error{"Expire output must be of type ExpireOutput."};
     }
@@ -217,7 +219,7 @@ void parse_and_set_expire_options(lua_State *lua_state,
         return;
     }
 
-    if (!column->is_geometry_column() || column->srid() != 3857) {
+    if (!column->is_geometry_column() || column->srid() != PROJ_SPHERE_MERC) {
         throw std::runtime_error{"Expire only allowed for geometry"
                                  " columns in Web Mercator projection."};
     }
@@ -416,6 +418,12 @@ void setup_flex_table_indexes(lua_State *lua_state, flex_table_t *table,
     lua_pop(lua_state, 1); // "indexes"
 }
 
+TRAMPOLINE_WRAPPED_OBJECT(table, tostring)
+TRAMPOLINE_WRAPPED_OBJECT(table, cluster)
+TRAMPOLINE_WRAPPED_OBJECT(table, columns)
+TRAMPOLINE_WRAPPED_OBJECT(table, name)
+TRAMPOLINE_WRAPPED_OBJECT(table, schema)
+
 } // anonymous namespace
 
 int setup_flex_table(lua_State *lua_state, std::vector<flex_table_t> *tables,
@@ -437,8 +445,71 @@ int setup_flex_table(lua_State *lua_state, std::vector<flex_table_t> *tables,
     void *ptr = lua_newuserdata(lua_state, sizeof(std::size_t));
     auto *num = new (ptr) std::size_t{};
     *num = tables->size() - 1;
-    luaL_getmetatable(lua_state, osm2pgsql_table_name);
+    luaL_getmetatable(lua_state, OSM2PGSQL_TABLE_CLASS);
     lua_setmetatable(lua_state, -2);
 
     return 1;
 }
+
+/**
+ * Define the osm2pgsql.Table class/metatable.
+ */
+void lua_wrapper_table_t::init(lua_State *lua_state)
+{
+    luaX_set_up_metatable(lua_state, "Table", OSM2PGSQL_TABLE_CLASS,
+                          {{"__tostring", lua_trampoline_table_tostring},
+                           {"insert", lua_trampoline_table_insert},
+                           {"name", lua_trampoline_table_name},
+                           {"schema", lua_trampoline_table_schema},
+                           {"cluster", lua_trampoline_table_cluster},
+                           {"columns", lua_trampoline_table_columns}});
+}
+
+int lua_wrapper_table_t::tostring() const
+{
+    std::string const str{fmt::format("osm2pgsql.Table[{}]", self().name())};
+    luaX_pushstring(lua_state(), str);
+
+    return 1;
+}
+
+int lua_wrapper_table_t::cluster() const noexcept
+{
+    lua_pushboolean(lua_state(), self().cluster_by_geom());
+    return 1;
+}
+
+int lua_wrapper_table_t::columns() const
+{
+    lua_createtable(lua_state(), (int)self().num_columns(), 0);
+
+    int n = 0;
+    for (auto const &column : self().columns()) {
+        lua_pushinteger(lua_state(), ++n);
+        lua_newtable(lua_state());
+
+        luaX_add_table_str(lua_state(), "name", column.name());
+        luaX_add_table_str(lua_state(), "type", column.type_name());
+        luaX_add_table_str(lua_state(), "sql_type", column.sql_type_name());
+        luaX_add_table_str(lua_state(), "sql_modifiers",
+                           column.sql_modifiers());
+        luaX_add_table_bool(lua_state(), "not_null", column.not_null());
+        luaX_add_table_bool(lua_state(), "create_only", column.create_only());
+
+        lua_rawset(lua_state(), -3);
+    }
+
+    return 1;
+}
+
+int lua_wrapper_table_t::name() const noexcept
+{
+    luaX_pushstring(lua_state(), self().name());
+    return 1;
+}
+
+int lua_wrapper_table_t::schema() const noexcept
+{
+    luaX_pushstring(lua_state(), self().schema());
+    return 1;
+}
