@@ -10,6 +10,8 @@
  * For a full list of authors see the git log.
  */
 
+#include "flex-lua-wrapper.hpp"
+
 #include <string>
 #include <vector>
 
@@ -17,11 +19,29 @@ class expire_output_t;
 class flex_table_t;
 struct lua_State;
 
-static char const *const osm2pgsql_table_name = "osm2pgsql.Table";
+static char const *const OSM2PGSQL_TABLE_CLASS = "osm2pgsql.Table";
 
 int setup_flex_table(lua_State *lua_state, std::vector<flex_table_t> *tables,
                      std::vector<expire_output_t> *expire_outputs,
                      std::string const &default_schema, bool updatable,
                      bool append_mode);
 
+class lua_wrapper_table_t : public lua_wrapper_base_t<flex_table_t>
+{
+public:
+    static void init(lua_State *lua_state);
+
+    lua_wrapper_table_t(lua_State *lua_state, flex_table_t *table)
+    : lua_wrapper_base_t(lua_state, table)
+    {
+    }
+
+    int tostring() const;
+    int cluster() const noexcept;
+    int columns() const;
+    int name() const noexcept;
+    int schema() const noexcept;
+
+}; // class lua_wrapper_table_t
+
 #endif // OSM2PGSQL_FLEX_LUA_TABLE_HPP
