@@ -9,6 +9,7 @@
 
 #include "canvas.hpp"
 
+#include "hex.hpp"
 #include "raster.hpp"
 #include "tile.hpp"
 
@@ -139,19 +140,3 @@ void canvas_t::merge(canvas_t const &other)
 {
     cv::bitwise_or(m_rast, other.m_rast, m_rast);
 }
-
-std::string to_hex(std::string const &in)
-{
-    std::string result;
-    result.reserve(in.size() * 2);
-
-    char const *const lookup_hex = "0123456789ABCDEF";
-
-    for (const auto c : in) {
-        unsigned int const num = static_cast<unsigned char>(c);
-        result += lookup_hex[(num >> 4U) & 0xfU];
-        result += lookup_hex[num & 0xfU];
-    }
-
-    return result;
-}
