@@ -10,9 +10,11 @@
 #include "gen-rivers.hpp"
 
 #include "geom-functions.hpp"
+#include "hex.hpp"
 #include "logging.hpp"
 #include "params.hpp"
 #include "pgsql.hpp"
+#include "projection.hpp"
 #include "util.hpp"
 #include "wkb.hpp"
 
@@ -41,6 +43,8 @@ gen_rivers_t::gen_rivers_t(pg_conn_t *connection, bool append, params_t *params)
                                get_params().get_string("src_areas")));
 }
 
+namespace {
+
 /// The data for a graph edge in the waterway network.
 struct edge_t
 {
@@ -76,8 +80,6 @@ bool operator<(geom::point_t a, edge_t const &b) noexcept
     return a < b.points[0];
 }
 
-namespace {
-
 void follow_chain_and_set_width(
     edge_t const &edge, std::vector<edge_t> *edges,
     std::map<geom::point_t, uint8_t> const &node_order,
@@ -264,7 +266,7 @@ SELECT "{id_column}", "{width_column}", "{name_column}", "{geom_column}"
             if (!name.empty()) {
                 names.emplace(id, name);
             }
-            auto const geom = ewkb_to_geom(decode_hex(result.get(i, 3)));
+            auto const geom = ewkb_to_geom(util::decode_hex(result.get(i, 3)));
 
             if (geom.is_linestring()) {
                 auto const &ls = geom.get<geom::linestring_t>();
@@ -340,10 +342,11 @@ SELECT "{id_column}", "{width_column}", "{name_column}", "{geom_column}"
     timer(m_timer_write).start();
     connection().exec("BEGIN");
     for (auto &edge : edges) {
-        geom::geometry_t const geom{std::move(edge.points), 3857};
+        geom::geometry_t const geom{std::move(edge.points), PROJ_SPHERE_MERC};
         auto const wkb = geom_to_ewkb(geom);
         connection().exec_prepared("ins", edge.id, edge.width,
-                                   get_name(names, edge.id), binary_param(wkb));
+                                   get_name(names, edge.id),
+                                   binary_param_t(wkb));
     }
     connection().exec("COMMIT");
     timer(m_timer_write).stop();
