@@ -3,7 +3,7 @@
  *
  * This file is part of osm2pgsql (https://osm2pgsql.org/).
  *
- * Copyright (C) 2006-2024 by the osm2pgsql developer community.
+ * Copyright (C) 2006-2025 by the osm2pgsql developer community.
  * For a full list of authors see the git log.
  */
 
@@ -42,6 +42,10 @@
 
 #include <lua.hpp>
 
+#include <potracelib.h>
+
+#include <opencv2/core/version.hpp>
+
 #include <algorithm>
 #include <atomic>
 #include <chrono>
@@ -76,7 +80,7 @@
 
 namespace {
 
-constexpr std::size_t const max_force_single_thread = 4;
+constexpr std::size_t MAX_FORCE_SINGLE_THREAD = 4;
 
 struct tile_extent
 {
@@ -220,7 +224,7 @@ void run_tile_gen(std::atomic_flag *error_flag,
                   std::mutex *mut, unsigned int n)
 {
     try {
-        logger::init_thread(n);
+        logger_t::init_thread(n);
 
         log_debug("Started generalizer thread for '{}'.",
                   master_generalizer->strategy());
@@ -496,7 +500,7 @@ private:
             }
         }
         log_debug("Need to process {} tiles.", tile_list.size());
-        if (m_jobs == 1 || tile_list.size() < max_force_single_thread) {
+        if (m_jobs == 1 || tile_list.size() < MAX_FORCE_SINGLE_THREAD) {
             log_debug("Running in single-threaded mode.");
             tile_processor_t tp{generalizer, tile_list.size()};
             while (!tile_list.empty()) {
@@ -516,8 +520,8 @@ private:
                                      m_connection_params, generalizer, params,
                                      zoom, &tile_list, &mut, n);
             }
-            for (auto &t : threads) {
-                t.join();
+            for (auto &thread : threads) {
+                thread.join();
             }
             if (error_flag.test_and_set()) {
                 throw std::runtime_error{
@@ -565,7 +569,7 @@ genproc_t::genproc_t(std::string const &filename,
     luaX_add_table_func(lua_state(), "run_sql", lua_trampoline_app_run_sql);
 
     lua_getglobal(lua_state(), "osm2pgsql");
-    if (luaL_newmetatable(lua_state(), osm2pgsql_expire_output_name) != 1) {
+    if (luaL_newmetatable(lua_state(), OSM2PGSQL_EXPIRE_OUTPUT_CLASS) != 1) {
         throw std::runtime_error{"Internal error: Lua newmetatable failed."};
     }
     lua_pushvalue(lua_state(), -1); // Copy of new metatable
@@ -642,6 +646,8 @@ int main(int argc, char *argv[])
 
         command_line_app_t app{
             "osm2pgsql-gen -- Generalize OpenStreetMap data\n"};
+        app.init_database_options();
+        app.init_logging_options(true, true);
 
         // ------------------------------------------------------------------
         // Main options
@@ -685,13 +691,16 @@ int main(int argc, char *argv[])
             return 0;
         }
 
-        log_info("osm2pgsql-gen version {}", get_osm2pgsql_version());
-        log_warn("This is an EXPERIMENTAL extension to osm2pgsql.");
-
         if (app.want_version()) {
+            print_version("osm2pgsql-gen");
+            fmt::print(stderr, "OpenCV {}\n", CV_VERSION);
+            fmt::print(stderr, "{}\n", potrace_version());
             return 0;
         }
 
+        log_info("osm2pgsql-gen version {}", get_osm2pgsql_version());
+        log_warn("This is an EXPERIMENTAL extension to osm2pgsql.");
+
         if (dbschema.empty()) {
             log_error("Schema must not be empty");
             return 2;
