@@ -45,6 +45,11 @@ public:
     constexpr double max_x() const noexcept { return m_max_x; }
     constexpr double max_y() const noexcept { return m_max_y; }
 
+    void set_min_x(double value) noexcept { m_min_x = value; }
+    void set_min_y(double value) noexcept { m_min_y = value; }
+    void set_max_x(double value) noexcept { m_max_x = value; }
+    void set_max_y(double value) noexcept { m_max_y = value; }
+
     constexpr double width() const noexcept { return m_max_x - m_min_x; }
     constexpr double height() const noexcept { return m_max_y - m_min_y; }
 
