@@ -11,6 +11,7 @@
 
 #include "geom-boost-adaptor.hpp"
 #include "overloaded.hpp"
+#include "projection.hpp"
 
 #include <algorithm>
 #include <cmath>
@@ -68,10 +69,10 @@ std::size_t num_geometries(geometry_t const &geom)
 
 namespace {
 
-class geometry_n_visitor
+class geometry_n_visitor_t
 {
 public:
-    geometry_n_visitor(geometry_t *output, std::size_t n)
+    geometry_n_visitor_t(geometry_t *output, std::size_t n)
     : m_output(output), m_n(n)
     {}
 
@@ -96,7 +97,7 @@ private:
     geometry_t *m_output;
     std::size_t m_n;
 
-}; // class geometry_n_visitor
+}; // class geometry_n_visitor_t
 
 } // anonymous namespace
 
@@ -108,7 +109,7 @@ void geometry_n(geometry_t *output, geometry_t const &input, std::size_t n)
         return;
     }
 
-    input.visit(geometry_n_visitor{output, n - 1});
+    input.visit(geometry_n_visitor_t{output, n - 1});
     output->set_srid(input.srid());
 }
 
@@ -125,14 +126,15 @@ namespace {
 
 void set_to_same_type(geometry_t *output, geometry_t const &input)
 {
+    // NOLINTNEXTLINE(performance-unnecessary-value-param)
     input.visit([&](auto in) { output->set<decltype(in)>(); });
 }
 
-class transform_visitor
+class transform_visitor_t
 {
 public:
-    explicit transform_visitor(geometry_t *output,
-                               reprojection const *reprojection)
+    explicit transform_visitor_t(geometry_t *output,
+                                 reprojection_t const *reprojection)
     : m_output(output), m_reprojection(reprojection)
     {}
 
@@ -155,40 +157,40 @@ public:
 
     void operator()(multipoint_t const &input) const
     {
-        auto &m = m_output->get<multipoint_t>();
-        m.reserve(input.num_geometries());
+        auto &mgeom = m_output->get<multipoint_t>();
+        mgeom.reserve(input.num_geometries());
         for (auto const point : input) {
-            m.add_geometry(project(point));
+            mgeom.add_geometry(project(point));
         }
     }
 
     void operator()(multilinestring_t const &input) const
     {
-        auto &m = m_output->set<multilinestring_t>();
-        m.reserve(input.num_geometries());
+        auto &mgeom = m_output->set<multilinestring_t>();
+        mgeom.reserve(input.num_geometries());
         for (auto const &line : input) {
-            transform_points(&m.add_geometry(), line);
+            transform_points(&mgeom.add_geometry(), line);
         }
     }
 
     void operator()(multipolygon_t const &input) const
     {
-        auto &m = m_output->set<multipolygon_t>();
-        m.reserve(input.num_geometries());
+        auto &mgeom = m_output->set<multipolygon_t>();
+        mgeom.reserve(input.num_geometries());
         for (auto const &polygon : input) {
-            transform_polygon(&m.add_geometry(), polygon);
+            transform_polygon(&mgeom.add_geometry(), polygon);
         }
     }
 
     void operator()(collection_t const &input) const
     {
-        auto &m = m_output->get<collection_t>();
-        m.reserve(input.num_geometries());
+        auto &mgeom = m_output->get<collection_t>();
+        mgeom.reserve(input.num_geometries());
         for (auto const &geom : input) {
-            auto &new_geom = m.add_geometry();
+            auto &new_geom = mgeom.add_geometry();
             set_to_same_type(&new_geom, geom);
             new_geom.set_srid(0);
-            geom.visit(transform_visitor{&new_geom, m_reprojection});
+            geom.visit(transform_visitor_t{&new_geom, m_reprojection});
         }
     }
 
@@ -218,23 +220,24 @@ private:
     }
 
     geometry_t *m_output;
-    reprojection const *m_reprojection;
+    reprojection_t const *m_reprojection;
 
-}; // class transform_visitor
+}; // class transform_visitor_t
 
 } // anonymous namespace
 
 void transform(geometry_t *output, geometry_t const &input,
-               reprojection const &reprojection)
+               reprojection_t const &reprojection)
 {
-    assert(input.srid() == 4326);
+    assert(input.srid() == PROJ_LATLONG);
 
     set_to_same_type(output, input);
     output->set_srid(reprojection.target_srs());
-    input.visit(transform_visitor{output, &reprojection});
+    input.visit(transform_visitor_t{output, &reprojection});
 }
 
-geometry_t transform(geometry_t const &input, reprojection const &reprojection)
+geometry_t transform(geometry_t const &input,
+                     reprojection_t const &reprojection)
 {
     geometry_t output;
     transform(&output, input, reprojection);
@@ -249,22 +252,22 @@ namespace {
  * Helper class for iterating over all points except the first one in a point
  * list.
  */
-class without_first
+class without_first_t
 {
 public:
-    explicit without_first(point_list_t const &list) : m_list(&list) {}
+    explicit without_first_t(point_list_t const &list) : m_list(&list) {}
 
     point_list_t::const_iterator begin()
     {
-        assert(m_list->begin() != m_list->end());
-        return std::next(m_list->begin());
+        assert(m_list->cbegin() != m_list->cend());
+        return std::next(m_list->cbegin());
     }
 
     point_list_t::const_iterator end() { return m_list->end(); }
 
 private:
     point_list_t const *m_list;
-}; // class without_first
+}; // class without_first_t
 
 void split_linestring(linestring_t const &line, double split_at,
                       multilinestring_t *output)
@@ -274,7 +277,7 @@ void split_linestring(linestring_t const &line, double split_at,
     linestring_t *out = &output->add_geometry();
     out->push_back(prev_pt);
 
-    for (auto const &this_pt : without_first(line)) {
+    for (auto const &this_pt : without_first_t(line)) {
         double const delta = distance(prev_pt, this_pt);
 
         // figure out if the addition of this point would take the total
@@ -384,7 +387,7 @@ double spherical_area(polygon_t const &geom)
 
 double spherical_area(geometry_t const &geom)
 {
-    assert(geom.srid() == 4326);
+    assert(geom.srid() == PROJ_LATLONG);
 
     return std::abs(geom.visit(overloaded{
         [&](geom::nullgeom_t const & /*input*/) { return 0.0; },
@@ -426,15 +429,15 @@ double length(geometry_t const &geom)
 
 namespace {
 
-class split_visitor
+class split_visitor_t
 {
 public:
-    split_visitor(std::vector<geometry_t> *output, int srid) noexcept
+    split_visitor_t(std::vector<geometry_t> *output, int srid) noexcept
     : m_output(output), m_srid(srid)
     {}
 
     template <typename T>
-    void operator()(T) const
+    void operator()(T const &) const
     {}
 
     // false positive https://github.com/llvm/llvm-project/issues/74738
@@ -460,7 +463,7 @@ private:
     std::vector<geometry_t> *m_output;
     int m_srid;
 
-}; // class split_visitor
+}; // class split_visitor_t
 
 } // anonymous namespace
 
@@ -469,7 +472,7 @@ std::vector<geometry_t> split_multi(geometry_t &&geom, bool split_multi)
     std::vector<geometry_t> output;
 
     if (split_multi && geom.is_multi()) {
-        visit(split_visitor{&output, geom.srid()}, std::move(geom));
+        visit(split_visitor_t{&output, geom.srid()}, std::move(geom));
     } else if (!geom.is_null()) {
         output.push_back(std::move(geom));
     }
@@ -544,8 +547,9 @@ namespace {
  * empty, do not add the first point returned by *it.
  */
 template <typename ITERATOR>
-void add_nodes_to_linestring(linestring_t *linestring, ITERATOR it,
-                             ITERATOR end)
+void add_nodes_to_linestring(
+    linestring_t *linestring, ITERATOR it,
+    ITERATOR end) // NOLINT(performance-unnecessary-value-param)
 {
     if (!linestring->empty()) {
         assert(it != end);
@@ -604,7 +608,7 @@ void line_merge(geometry_t *output, geometry_t const &input)
     std::vector<endpoint_t> endpoints;
 
     // ...and a list of connections.
-    constexpr auto const NOCONN = std::numeric_limits<std::size_t>::max();
+    constexpr std::size_t NOCONN = std::numeric_limits<std::size_t>::max();
 
     struct connection_t
     {
