@@ -88,11 +88,9 @@ bool point_to_ring_distance_squared(point_t point, ring_t const &ring,
             inside = !inside;
         }
 
-        double const d =
+        double const dist_squared =
             point_to_segment_distance_squared(point, a, b, stretch);
-        if (d < *min_dist_squared) {
-            *min_dist_squared = d;
-        }
+        *min_dist_squared = std::min(dist_squared, *min_dist_squared);
     }
 
     return inside;
@@ -118,28 +116,29 @@ auto point_to_polygon_distance(point_t point, polygon_t const &polygon,
     return (inside ? 1 : -1) * std::sqrt(min_dist_squared);
 }
 
-struct Cell
+struct cell_t
 {
-    static constexpr double const SQRT2 = 1.4142135623730951;
+    static constexpr double SQRT2 = 1.4142135623730951;
 
-    Cell(point_t c, double h, polygon_t const &polygon, double stretch)
+    cell_t(point_t c, double h, polygon_t const &polygon, double stretch)
     : center(c), half_size(h),
       dist(point_to_polygon_distance(center, polygon, stretch)),
       max(dist + half_size * SQRT2)
-    {}
+    {
+    }
 
     point_t center;   // cell center
     double half_size; // half the cell size
     double dist;      // distance from cell center to polygon
     double max;       // max distance to polygon within a cell
 
-    friend bool operator<(Cell const &a, Cell const &b) noexcept
+    friend bool operator<(cell_t const &a, cell_t const &b) noexcept
     {
         return a.max < b.max;
     }
 };
 
-Cell make_centroid_cell(polygon_t const &polygon, double stretch)
+cell_t make_centroid_cell(polygon_t const &polygon, double stretch)
 {
     point_t centroid{0, 0};
     boost::geometry::centroid(polygon, centroid);
@@ -149,7 +148,7 @@ Cell make_centroid_cell(polygon_t const &polygon, double stretch)
 
 } // anonymous namespace
 
-point_t pole_of_inaccessibility(const polygon_t &polygon, double precision,
+point_t pole_of_inaccessibility(polygon_t const &polygon, double precision,
                                 double stretch)
 {
     assert(stretch > 0);
@@ -158,9 +157,7 @@ point_t pole_of_inaccessibility(const polygon_t &polygon, double precision,
 
     double const min_precision =
         std::max(envelope.width(), envelope.height()) / 1000.0;
-    if (min_precision > precision) {
-        precision = min_precision;
-    }
+    precision = std::max(min_precision, precision);
 
     box_t const stretched_envelope{envelope.min_x(), envelope.min_y() * stretch,
                                    envelope.max_x(),
@@ -170,7 +167,7 @@ point_t pole_of_inaccessibility(const polygon_t &polygon, double precision,
         return envelope.min();
     }
 
-    std::priority_queue<Cell, std::vector<Cell>> cell_queue;
+    std::priority_queue<cell_t, std::vector<cell_t>> cell_queue;
 
     // cover polygon with initial cells
     if (stretched_envelope.width() == stretched_envelope.height()) {
@@ -205,7 +202,7 @@ point_t pole_of_inaccessibility(const polygon_t &polygon, double precision,
     auto best_cell = make_centroid_cell(polygon, stretch);
 
     // second guess: bounding box centroid
-    Cell const bbox_cell{stretched_envelope.center(), 0, polygon, stretch};
+    cell_t const bbox_cell{stretched_envelope.center(), 0, polygon, stretch};
     if (bbox_cell.dist > best_cell.dist) {
         best_cell = bbox_cell;
     }
@@ -229,10 +226,10 @@ point_t pole_of_inaccessibility(const polygon_t &polygon, double precision,
         auto const h = cell.half_size / 2.0;
         auto const center = cell.center;
 
-        for (auto dy : {-h, h}) {
-            for (auto dx : {-h, h}) {
-                Cell const c{point_t{center.x() + dx, center.y() + dy}, h,
-                             polygon, stretch};
+        for (auto const dy : {-h, h}) {
+            for (auto const dx : {-h, h}) {
+                cell_t const c{point_t{center.x() + dx, center.y() + dy}, h,
+                               polygon, stretch};
                 if (c.max > best_cell.dist) {
                     cell_queue.push(c);
                 }
