@@ -36,7 +36,7 @@ void *luaX_get_context(lua_State *lua_state) noexcept
 namespace {
 
 // Unique key for lua registry
-constexpr char const *const osm2pgsql_output_flex = "osm2pgsql_output_flex";
+constexpr char const *const OSM2PGSQL_OUTPUT_FLEX = "osm2pgsql_output_flex";
 
 } // anonymous namespace
 
@@ -44,7 +44,7 @@ void luaX_set_context(lua_State *lua_state, void *ptr) noexcept
 {
     assert(lua_state);
     assert(ptr);
-    lua_pushlightuserdata(lua_state, (void *)osm2pgsql_output_flex);
+    lua_pushlightuserdata(lua_state, (void *)OSM2PGSQL_OUTPUT_FLEX);
     lua_pushlightuserdata(lua_state, ptr);
     lua_settable(lua_state, LUA_REGISTRYINDEX);
 }
@@ -52,7 +52,7 @@ void luaX_set_context(lua_State *lua_state, void *ptr) noexcept
 void *luaX_get_context(lua_State *lua_state) noexcept
 {
     assert(lua_state);
-    lua_pushlightuserdata(lua_state, (void *)osm2pgsql_output_flex);
+    lua_pushlightuserdata(lua_state, (void *)OSM2PGSQL_OUTPUT_FLEX);
     lua_gettable(lua_state, LUA_REGISTRYINDEX);
     auto *const ptr = lua_touserdata(lua_state, -1);
     assert(ptr);
@@ -76,10 +76,10 @@ void luaX_add_table_str(lua_State *lua_state, char const *key,
 }
 
 void luaX_add_table_str(lua_State *lua_state, char const *key,
-                        char const *value, std::size_t size) noexcept
+                        std::string_view value) noexcept
 {
     lua_pushstring(lua_state, key);
-    lua_pushlstring(lua_state, value, size);
+    luaX_pushstring(lua_state, value);
     lua_rawset(lua_state, -3);
 }
 
@@ -115,6 +115,32 @@ void luaX_add_table_func(lua_State *lua_state, char const *key,
     lua_rawset(lua_state, -3);
 }
 
+void luaX_set_up_metatable(
+    lua_State *lua_state, char const *name, char const *luaclass,
+    std::initializer_list<std::pair<char const *, lua_CFunction>> map)
+
+{
+    lua_getglobal(lua_state, "osm2pgsql");
+    if (luaL_newmetatable(lua_state, luaclass) != 1) {
+        throw std::runtime_error{"Internal error: Lua newmetatable failed."};
+    }
+    lua_pushvalue(lua_state, -1); // Copy of new metatable
+
+    // Add metatable under the specified name so we can access it from Lua
+    lua_setfield(lua_state, -3, name);
+
+    // Now add functions to metatable
+    lua_pushvalue(lua_state, -1);
+    lua_setfield(lua_state, -2, "__index");
+    for (auto const &[key, func] : map) {
+        lua_pushstring(lua_state, key);
+        lua_pushcfunction(lua_state, func);
+        lua_rawset(lua_state, -3);
+    }
+
+    lua_settop(lua_state, 0);
+}
+
 char const *luaX_get_table_string(lua_State *lua_state, char const *key,
                                   int table_index, char const *error_msg)
 {
