@@ -47,8 +47,8 @@
 
 namespace {
 
-void send_id_list(pg_conn_t const &db_connection,
-                         std::string const &table, idlist_t const &ids)
+void send_id_list(pg_conn_t const &db_connection, std::string const &table,
+                  idlist_t const &ids)
 {
     std::string data;
     for (auto const id : ids) {
@@ -73,8 +73,8 @@ void load_id_list(pg_conn_t const &db_connection, std::string const &table,
 
 } // anonymous namespace
 
-middle_pgsql_t::table_desc::table_desc(options_t const &options,
-                                       std::string_view name)
+middle_pgsql_t::table_desc_t::table_desc_t(options_t const &options,
+                                           std::string_view name)
 : m_copy_target(std::make_shared<db_target_descr_t>(
       options.middle_dbschema, fmt::format("{}_{}", options.prefix, name),
       "id"))
@@ -93,13 +93,13 @@ void middle_pgsql_t::dbexec(std::string_view templ) const
     m_db_connection.exec(render_template(templ));
 }
 
-void middle_query_pgsql_t::prepare(std::string_view stmt,
+void middle_query_pgsql_t::prepare(std::string const &stmt,
                                    std::string const &sql_cmd) const
 {
     m_db_connection.prepare(stmt, fmt::runtime(sql_cmd));
 }
 
-void middle_pgsql_t::table_desc::drop_table(
+void middle_pgsql_t::table_desc_t::drop_table(
     pg_conn_t const &db_connection) const
 {
     util::timer_t timer;
@@ -110,7 +110,7 @@ void middle_pgsql_t::table_desc::drop_table(
              util::human_readable_duration(timer.stop()));
 }
 
-void middle_pgsql_t::table_desc::init_max_id(pg_conn_t const &db_connection)
+void middle_pgsql_t::table_desc_t::init_max_id(pg_conn_t const &db_connection)
 {
     auto const qual_name = qualified_name(schema(), name());
     auto const res = db_connection.exec("SELECT max(id) FROM {}", qual_name);
@@ -151,10 +151,10 @@ void pgsql_parse_json_tags(char const *string, osmium::memory::Buffer *buffer,
 /**
  * Helper class for parsing relation members encoded in JSON.
  */
-class member_list_json_builder
+class member_list_json_builder_t
 {
 public:
-    explicit member_list_json_builder(
+    explicit member_list_json_builder_t(
         osmium::builder::RelationMemberListBuilder *builder)
     : m_builder(builder)
     {}
@@ -171,7 +171,7 @@ public:
     }
 
     static bool number_float(nlohmann::json::number_float_t /*val*/,
-                             const nlohmann::json::string_t & /*s*/)
+                             nlohmann::json::string_t const & /*s*/)
     {
         return true;
     }
@@ -228,25 +228,25 @@ public:
     static bool end_array() { return true; }
 
     static bool parse_error(std::size_t /*position*/,
-                            const std::string & /*last_token*/,
-                            const nlohmann::json::exception &ex)
+                            std::string const & /*last_token*/,
+                            nlohmann::json::exception const &ex)
     {
         throw ex;
     }
 
 private:
-    osmium::builder::RelationMemberListBuilder *m_builder;
     std::string m_role;
+    osmium::builder::RelationMemberListBuilder *m_builder;
     osmium::object_id_type m_ref = 0;
     osmium::item_type m_type = osmium::item_type::undefined;
-    enum class next_val
+    enum class next_val : std::uint8_t
     {
         none,
         type,
         ref,
         role
     } m_next_val = next_val::none;
-};
+}; // class member_list_json_builder_t
 
 template <typename T>
 void pgsql_parse_json_members(char const *string,
@@ -257,7 +257,7 @@ void pgsql_parse_json_members(char const *string,
     }
 
     osmium::builder::RelationMemberListBuilder builder{*buffer, obuilder};
-    member_list_json_builder parser{&builder};
+    member_list_json_builder_t parser{&builder};
     nlohmann::json::sax_parse(string, &parser);
 }
 
@@ -447,7 +447,8 @@ void middle_pgsql_t::node(osmium::Node const &node)
     }
 }
 
-void middle_pgsql_t::way(osmium::Way const &way) {
+void middle_pgsql_t::way(osmium::Way const &way)
+{
     assert(m_middle_state == middle_state::way);
 
     if (way.deleted()) {
@@ -460,7 +461,8 @@ void middle_pgsql_t::way(osmium::Way const &way) {
     }
 }
 
-void middle_pgsql_t::relation(osmium::Relation const &relation) {
+void middle_pgsql_t::relation(osmium::Relation const &relation)
+{
     assert(m_middle_state == middle_state::relation);
 
     if (relation.deleted()) {
@@ -985,7 +987,7 @@ void middle_pgsql_t::after_relations()
 middle_query_pgsql_t::middle_query_pgsql_t(
     connection_params_t const &connection_params,
     std::shared_ptr<node_locations_t> cache,
-    std::shared_ptr<node_persistent_cache> persistent_cache,
+    std::shared_ptr<node_persistent_cache_t> persistent_cache,
     middle_pgsql_options const &options)
 : m_db_connection(connection_params, "middle.query"), m_cache(std::move(cache)),
   m_persistent_cache(std::move(persistent_cache)), m_store_options(options)
@@ -1168,7 +1170,7 @@ void middle_pgsql_t::stop()
     if (m_options->droptemp) {
         // Dropping the tables is fast, so do it synchronously to guarantee
         // that the space is freed before creating the other indices.
-        for (auto &table : m_tables) {
+        for (auto const &table : m_tables) {
             table.drop_table(m_db_connection);
         }
     } else if (!m_options->append) {
@@ -1247,7 +1249,7 @@ middle_pgsql_t::middle_pgsql_t(std::shared_ptr<thread_pool_t> thread_pool,
         m_store_options.untagged_nodes = true;
     } else {
         m_store_options.use_flat_node_file = true;
-        m_persistent_cache = std::make_shared<node_persistent_cache>(
+        m_persistent_cache = std::make_shared<node_persistent_cache_t>(
             options->flat_node_file, !options->append, options->droptemp);
     }
 
@@ -1255,9 +1257,9 @@ middle_pgsql_t::middle_pgsql_t(std::shared_ptr<thread_pool_t> thread_pool,
 
     init_params(&m_params, *options);
 
-    m_tables.nodes() = table_desc{*options, "nodes"};
-    m_tables.ways() = table_desc{*options, "ways"};
-    m_tables.relations() = table_desc{*options, "rels"};
+    m_tables.nodes() = table_desc_t{*options, "nodes"};
+    m_tables.ways() = table_desc_t{*options, "ways"};
+    m_tables.relations() = table_desc_t{*options, "rels"};
 }
 
 void middle_pgsql_t::set_requirements(
@@ -1270,8 +1272,7 @@ void middle_pgsql_t::set_requirements(
     log_debug("  with_attributes: {}", m_store_options.with_attributes);
 }
 
-std::shared_ptr<middle_query_t>
-middle_pgsql_t::get_query_instance()
+std::shared_ptr<middle_query_t> middle_pgsql_t::get_query_instance()
 {
     // NOTE: this is thread safe for use in pending async processing only
     // because during that process they are only read from
