@@ -79,7 +79,7 @@ middle_ram_t::middle_ram_t(std::shared_ptr<thread_pool_t> thread_pool,
     }
 
     if (!options->flat_node_file.empty()) {
-        m_persistent_cache = std::make_shared<node_persistent_cache>(
+        m_persistent_cache = std::make_shared<node_persistent_cache_t>(
             options->flat_node_file, !options->append, options->droptemp);
     }
 }
@@ -341,26 +341,24 @@ middle_ram_t::rel_members_get(osmium::Relation const &rel,
         switch (member.type()) {
         case osmium::item_type::node:
             if (m_store_options.nodes) {
-                auto const offset =
-                    m_object_index.nodes().get(member.ref());
+                auto const offset = m_object_index.nodes().get(member.ref());
                 if (offset != ordered_index_t::not_found_value()) {
                     buffer->add_item(m_object_buffer.get<osmium::Node>(offset));
                     buffer->commit();
                     ++count;
+                    continue;
                 }
-            } else {
-                {
-                    osmium::builder::NodeBuilder builder{*buffer};
-                    builder.set_id(member.ref());
-                }
-                buffer->commit();
-                ++count;
             }
+            {
+                osmium::builder::NodeBuilder builder{*buffer};
+                builder.set_id(member.ref());
+            }
+            buffer->commit();
+            ++count;
             break;
         case osmium::item_type::way:
             if (m_store_options.ways) {
-                auto const offset =
-                    m_object_index.ways().get(member.ref());
+                auto const offset = m_object_index.ways().get(member.ref());
                 if (offset != ordered_index_t::not_found_value()) {
                     buffer->add_item(m_object_buffer.get<osmium::Way>(offset));
                     buffer->commit();
