@@ -25,7 +25,7 @@
 #include <string>
 #include <utility>
 
-class node_persistent_cache;
+class node_persistent_cache_t;
 class thread_pool_t;
 
 /**
@@ -130,7 +130,7 @@ private:
     middle_ram_options m_store_options;
 
     /// File cache
-    std::shared_ptr<node_persistent_cache> m_persistent_cache;
+    std::shared_ptr<node_persistent_cache_t> m_persistent_cache;
 
 }; // class middle_ram_t
 
