@@ -7,15 +7,19 @@
  * For a full list of authors see the git log.
  */
 
+#include "output-flex.hpp"
+
 #include "db-copy.hpp"
 #include "debug-output.hpp"
 #include "expire-output.hpp"
 #include "expire-tiles.hpp"
 #include "flex-index.hpp"
+#include "flex-lua-expire-output.hpp"
 #include "flex-lua-geom.hpp"
 #include "flex-lua-index.hpp"
+#include "flex-lua-locator.hpp"
 #include "flex-lua-table.hpp"
-#include "flex-lua-expire-output.hpp"
+#include "flex-lua-wrapper.hpp"
 #include "flex-write.hpp"
 #include "format.hpp"
 #include "geom-from-osm.hpp"
@@ -27,9 +31,9 @@
 #include "middle.hpp"
 #include "options.hpp"
 #include "osmtypes.hpp"
-#include "output-flex.hpp"
-#include "pgsql.hpp"
 #include "pgsql-capabilities.hpp"
+#include "pgsql.hpp"
+#include "projection.hpp"
 #include "properties.hpp"
 #include "reprojection.hpp"
 #include "thread-pool.hpp"
@@ -75,6 +79,7 @@ std::mutex lua_mutex;
         }                                                                      \
     }
 
+TRAMPOLINE(app_define_locator, define_locator)
 TRAMPOLINE(app_define_table, define_table)
 TRAMPOLINE(app_define_expire_output, define_expire_output)
 TRAMPOLINE(app_get_bbox, get_bbox)
@@ -87,22 +92,10 @@ TRAMPOLINE(app_as_multilinestring, as_multilinestring)
 TRAMPOLINE(app_as_multipolygon, as_multipolygon)
 TRAMPOLINE(app_as_geometrycollection, as_geometrycollection)
 
-TRAMPOLINE(table_name, name)
-TRAMPOLINE(table_schema, schema)
-TRAMPOLINE(table_cluster, cluster)
-TRAMPOLINE(table_insert, insert)
-TRAMPOLINE(table_columns, columns)
-TRAMPOLINE(table_tostring, __tostring)
-
-TRAMPOLINE(expire_output_minzoom, minzoom)
-TRAMPOLINE(expire_output_maxzoom, maxzoom)
-TRAMPOLINE(expire_output_filename, filename)
-TRAMPOLINE(expire_output_schema, schema)
-TRAMPOLINE(expire_output_table, table)
-TRAMPOLINE(expire_output_tostring, __tostring)
-
 } // anonymous namespace
 
+TRAMPOLINE(table_insert, insert)
+
 prepared_lua_function_t::prepared_lua_function_t(lua_State *lua_state,
                                                  calling_context context,
                                                  char const *name, int nresults)
@@ -128,7 +121,7 @@ prepared_lua_function_t::prepared_lua_function_t(lua_State *lua_state,
 
 namespace {
 
-std::string_view const osm2pgsql_object_metatable = "osm2pgsql.OSMObject";
+char const *const OSM2PGSQL_OSMOBJECT_CLASS = "osm2pgsql.OSMObject";
 
 void push_osm_object_to_lua_stack(lua_State *lua_state,
                                   osmium::OSMObject const &object)
@@ -140,9 +133,9 @@ void push_osm_object_to_lua_stack(lua_State *lua_state,
      * timestamp, changeset, uid, user). For ways there are 2 more (is_closed,
      * nodes), for relations 1 more (members).
      */
-    constexpr int const max_table_size = 10;
+    constexpr int MAX_TABLE_SIZE = 10;
 
-    lua_createtable(lua_state, 0, max_table_size);
+    lua_createtable(lua_state, 0, MAX_TABLE_SIZE);
 
     luaX_add_table_int(lua_state, "id", object.id());
 
@@ -166,39 +159,42 @@ void push_osm_object_to_lua_stack(lua_State *lua_state,
         luaX_add_table_str(lua_state, "user", object.user());
     }
 
-    if (object.type() == osmium::item_type::way) {
-        auto const &way = static_cast<osmium::Way const &>(object);
-        luaX_add_table_bool(lua_state, "is_closed",
-                            !way.nodes().empty() && way.is_closed());
-        luaX_add_table_array(lua_state, "nodes", way.nodes(),
-                             [&](osmium::NodeRef const &wn) {
-                                 lua_pushinteger(lua_state, wn.ref());
-                             });
-    } else if (object.type() == osmium::item_type::relation) {
-        auto const &relation = static_cast<osmium::Relation const &>(object);
-        luaX_add_table_array(
-            lua_state, "members", relation.members(),
-            [&](osmium::RelationMember const &member) {
-                lua_createtable(lua_state, 0, 3);
-                std::array<char, 2> tmp{"x"};
-                tmp[0] = osmium::item_type_to_char(member.type());
-                luaX_add_table_str(lua_state, "type", tmp.data());
-                luaX_add_table_int(lua_state, "ref", member.ref());
-                luaX_add_table_str(lua_state, "role", member.role());
-            });
-    }
+    if (!object.deleted()) {
+        if (object.type() == osmium::item_type::way) {
+            auto const &way = static_cast<osmium::Way const &>(object);
+            luaX_add_table_bool(lua_state, "is_closed",
+                                !way.nodes().empty() && way.is_closed());
+            luaX_add_table_array(lua_state, "nodes", way.nodes(),
+                                 [&](osmium::NodeRef const &wn) {
+                                     lua_pushinteger(lua_state, wn.ref());
+                                 });
+        } else if (object.type() == osmium::item_type::relation) {
+            auto const &relation =
+                static_cast<osmium::Relation const &>(object);
+            luaX_add_table_array(
+                lua_state, "members", relation.members(),
+                [&](osmium::RelationMember const &member) {
+                    lua_createtable(lua_state, 0, 3);
+                    std::array<char, 2> tmp{"x"};
+                    tmp[0] = osmium::item_type_to_char(member.type());
+                    luaX_add_table_str(lua_state, "type", tmp.data());
+                    luaX_add_table_int(lua_state, "ref", member.ref());
+                    luaX_add_table_str(lua_state, "role", member.role());
+                });
+        }
 
-    lua_pushliteral(lua_state, "tags");
-    lua_createtable(lua_state, 0, (int)object.tags().size());
-    for (auto const &tag : object.tags()) {
-        luaX_add_table_str(lua_state, tag.key(), tag.value());
-    }
-    lua_rawset(lua_state, -3);
+        lua_pushliteral(lua_state, "tags");
+        lua_createtable(lua_state, 0, (int)object.tags().size());
+        for (auto const &tag : object.tags()) {
+            luaX_add_table_str(lua_state, tag.key(), tag.value());
+        }
+        lua_rawset(lua_state, -3);
 
-    // Set the metatable of this object
-    luaX_pushstring(lua_state, osm2pgsql_object_metatable);
-    lua_gettable(lua_state, LUA_REGISTRYINDEX);
-    lua_setmetatable(lua_state, -2);
+        // Set the metatable of this object
+        lua_pushstring(lua_state, OSM2PGSQL_OSMOBJECT_CLASS);
+        lua_gettable(lua_state, LUA_REGISTRYINDEX);
+        lua_setmetatable(lua_state, -2);
+    }
 }
 
 /**
@@ -233,27 +229,27 @@ std::size_t idx_from_param(lua_State *lua_state, char const *type_name)
 }
 
 template <typename CONTAINER>
-typename CONTAINER::value_type const &get_from_idx_param(lua_State *lua_state,
-                                                         CONTAINER *container,
-                                                         char const *type_name)
+typename CONTAINER::value_type &get_from_idx_param(lua_State *lua_state,
+                                                   CONTAINER *container,
+                                                   char const *type_name)
 {
-    if (lua_gettop(lua_state) != 1) {
-        throw fmt_error("Need exactly one parameter of type {}.", type_name);
+    if (lua_gettop(lua_state) < 1) {
+        throw fmt_error("Argument #1 has to be of type {}.", type_name);
     }
 
-    auto const &item = container->at(idx_from_param(lua_state, type_name));
+    auto &item = container->at(idx_from_param(lua_state, type_name));
     lua_remove(lua_state, 1);
     return item;
 }
 
 std::size_t get_nodes(middle_query_t const &middle, osmium::Way *way)
 {
-    constexpr std::size_t const max_missing_nodes = 100;
+    constexpr std::size_t MAX_MISSING_NODES = 100;
     static std::size_t count_missing_nodes = 0;
 
     auto const count = middle.nodes_get_list(&way->nodes());
 
-    if (count_missing_nodes <= max_missing_nodes &&
+    if (count_missing_nodes <= MAX_MISSING_NODES &&
         count != way->nodes().size()) {
         util::string_joiner_t id_list{','};
         for (auto const &nr : way->nodes()) {
@@ -265,10 +261,10 @@ std::size_t get_nodes(middle_query_t const &middle, osmium::Way *way)
 
         log_debug("Missing nodes in way {}: {}", way->id(), id_list());
 
-        if (count_missing_nodes > max_missing_nodes) {
+        if (count_missing_nodes > MAX_MISSING_NODES) {
             log_debug("Reported more than {} missing nodes, no further missing "
                       "nodes will be reported!",
-                      max_missing_nodes);
+                      MAX_MISSING_NODES);
         }
     }
 
@@ -285,7 +281,7 @@ void flush_tables(std::vector<table_connection_t> &table_connections)
 void create_expire_tables(std::vector<expire_output_t> const &expire_outputs,
                           connection_params_t const &connection_params)
 {
-    if (std::all_of(expire_outputs.begin(), expire_outputs.end(),
+    if (std::all_of(expire_outputs.cbegin(), expire_outputs.cend(),
                     [](auto const &expire_output) {
                         return expire_output.table().empty();
                     })) {
@@ -320,7 +316,7 @@ void check_for_object(lua_State *lua_state, char const *const function_name)
     }
 
     if (lua_getmetatable(lua_state, 1)) {
-        luaL_getmetatable(lua_state, osm2pgsql_object_metatable.data());
+        luaL_getmetatable(lua_state, OSM2PGSQL_OSMOBJECT_CLASS);
         if (lua_rawequal(lua_state, -1, -2)) {
             lua_pop(lua_state, 2); // remove the two metatables
             return;
@@ -334,6 +330,54 @@ void check_for_object(lua_State *lua_state, char const *const function_name)
              function_name);
 }
 
+/**
+ * Expects a Lua (hash) table on the stack, reads the field with name of the
+ * 'type' parameter which must be either nil or a Lua (array) table, in which
+ * case all (integer) ids in that table are reads into the 'ids' out
+ * parameter.
+ */
+void get_object_ids(lua_State *lua_state, char const *const type, idlist_t *ids)
+{
+    lua_getfield(lua_state, -1, type);
+    int const ltype = lua_type(lua_state, -1);
+
+    if (ltype == LUA_TNIL) {
+        lua_pop(lua_state, 1);
+        return;
+    }
+
+    if (ltype != LUA_TTABLE) {
+        lua_pop(lua_state, 1);
+        throw fmt_error(
+            "Table returned from select_relation_members() contains '{}' "
+            "field, but it isn't an array table.",
+            type);
+    }
+
+    if (!luaX_is_array(lua_state)) {
+        lua_pop(lua_state, 1);
+        throw fmt_error(
+            "Table returned from select_relation_members() contains '{}' "
+            "field, but it isn't an array table.",
+            type);
+    }
+
+    luaX_for_each(lua_state, [&]() {
+        osmid_t const id = lua_tointeger(lua_state, -1);
+        if (id == 0) {
+            throw fmt_error(
+                "Table returned from select_relation_members() contains "
+                "'{}' field, which must contain an array of non-zero "
+                "integer node ids.",
+                type);
+        }
+
+        ids->push_back(id);
+    });
+
+    lua_pop(lua_state, 1);
+}
+
 } // anonymous namespace
 
 /**
@@ -387,9 +431,9 @@ int output_flex_t::app_get_bbox()
         osmium::Box bbox;
 
         // Bounding boxes of all the member nodes
-        for (auto const &wnl :
-             m_relation_cache.members_buffer().select<osmium::WayNodeList>()) {
-            bbox.extend(wnl.envelope());
+        for (auto const &node :
+             m_relation_cache.members_buffer().select<osmium::Node>()) {
+            bbox.extend(node.location());
         }
 
         // Bounding boxes of all the member ways
@@ -528,6 +572,17 @@ int output_flex_t::app_as_geometrycollection()
     return 1;
 }
 
+int output_flex_t::app_define_locator()
+{
+    if (m_calling_context != calling_context::main) {
+        throw std::runtime_error{
+            "Locators have to be defined in the"
+            " main Lua code, not in any of the callbacks."};
+    }
+
+    return setup_flex_locator(lua_state(), m_locators.get());
+}
+
 int output_flex_t::app_define_table()
 {
     if (m_calling_context != calling_context::main) {
@@ -554,26 +609,22 @@ int output_flex_t::app_define_expire_output()
                                     m_expire_outputs.get());
 }
 
-flex_table_t const &output_flex_t::get_table_from_param()
+flex_table_t &output_flex_t::get_table_from_param()
 {
     return get_from_idx_param(lua_state(), m_tables.get(),
-                              osm2pgsql_table_name);
+                              OSM2PGSQL_TABLE_CLASS);
 }
 
-expire_output_t const &output_flex_t::get_expire_output_from_param()
+expire_output_t &output_flex_t::get_expire_output_from_param()
 {
     return get_from_idx_param(lua_state(), m_expire_outputs.get(),
-                              osm2pgsql_expire_output_name);
+                              OSM2PGSQL_EXPIRE_OUTPUT_CLASS);
 }
 
-int output_flex_t::table_tostring()
+locator_t &output_flex_t::get_locator_from_param()
 {
-    auto const &table = get_table_from_param();
-
-    std::string const str{fmt::format("osm2pgsql.Table[{}]", table.name())};
-    luaX_pushstring(lua_state(), str);
-
-    return 1;
+    return get_from_idx_param(lua_state(), m_locators.get(),
+                              OSM2PGSQL_LOCATOR_CLASS);
 }
 
 bool output_flex_t::way_cache_t::init(middle_query_t const &middle, osmid_t id)
@@ -698,7 +749,7 @@ int output_flex_t::table_insert()
 
     // The first parameter is the table object.
     auto &table_connection = m_table_connections.at(
-        idx_from_param(lua_state(), osm2pgsql_table_name));
+        idx_from_param(lua_state(), OSM2PGSQL_TABLE_CLASS));
 
     // The second parameter must be a Lua table with the contents for the
     // fields.
@@ -727,7 +778,7 @@ int output_flex_t::table_insert()
             }
         }
         table_connection.increment_insert_counter();
-    } catch (not_null_exception const &e) {
+    } catch (not_null_exception_t const &e) {
         copy_mgr->rollback_line();
         lua_pushboolean(lua_state(), false);
         lua_pushliteral(lua_state(), "null value in not null column.");
@@ -743,107 +794,6 @@ int output_flex_t::table_insert()
     return 1;
 }
 
-int output_flex_t::table_columns()
-{
-    auto const &table = get_table_from_param();
-
-    lua_createtable(lua_state(), (int)table.num_columns(), 0);
-
-    int n = 0;
-    for (auto const &column : table.columns()) {
-        lua_pushinteger(lua_state(), ++n);
-        lua_newtable(lua_state());
-
-        luaX_add_table_str(lua_state(), "name", column.name().c_str());
-        luaX_add_table_str(lua_state(), "type", column.type_name().c_str());
-        luaX_add_table_str(lua_state(), "sql_type",
-                           column.sql_type_name().c_str());
-        luaX_add_table_str(lua_state(), "sql_modifiers",
-                           column.sql_modifiers().c_str());
-        luaX_add_table_bool(lua_state(), "not_null", column.not_null());
-        luaX_add_table_bool(lua_state(), "create_only", column.create_only());
-
-        lua_rawset(lua_state(), -3);
-    }
-    return 1;
-}
-
-int output_flex_t::table_name()
-{
-    auto const &table = get_table_from_param();
-    luaX_pushstring(lua_state(), table.name());
-    return 1;
-}
-
-int output_flex_t::table_schema()
-{
-    auto const &table = get_table_from_param();
-    luaX_pushstring(lua_state(), table.schema());
-    return 1;
-}
-
-int output_flex_t::table_cluster()
-{
-    auto const &table = get_table_from_param();
-    lua_pushboolean(lua_state(), table.cluster_by_geom());
-    return 1;
-}
-
-int output_flex_t::expire_output_tostring()
-{
-    auto const &expire_output = get_expire_output_from_param();
-
-    std::string const str =
-        fmt::format("osm2pgsql.ExpireOutput[minzoom={},maxzoom={},filename={},"
-                    "schema={},table={}]",
-                    expire_output.minzoom(), expire_output.maxzoom(),
-                    expire_output.filename(), expire_output.schema(),
-                    expire_output.table());
-    luaX_pushstring(lua_state(), str);
-
-    return 1;
-}
-
-int output_flex_t::expire_output_minzoom()
-{
-    auto const &expire_output = get_expire_output_from_param();
-
-    lua_pushinteger(lua_state(), expire_output.minzoom());
-    return 1;
-}
-
-int output_flex_t::expire_output_maxzoom()
-{
-    auto const &expire_output = get_expire_output_from_param();
-
-    lua_pushinteger(lua_state(), expire_output.maxzoom());
-    return 1;
-}
-
-int output_flex_t::expire_output_filename()
-{
-    auto const &expire_output = get_expire_output_from_param();
-
-    luaX_pushstring(lua_state(), expire_output.filename());
-    return 1;
-}
-
-int output_flex_t::expire_output_schema()
-{
-    auto const &expire_output = get_expire_output_from_param();
-
-    luaX_pushstring(lua_state(), expire_output.schema());
-    return 1;
-}
-
-int output_flex_t::expire_output_table()
-{
-    auto const &expire_output = get_expire_output_from_param();
-
-    luaX_pushstring(lua_state(), expire_output.table());
-    return 1;
-}
-
 void output_flex_t::call_lua_function(prepared_lua_function_t func)
 {
     lua_pushvalue(lua_state(), func.index());
@@ -858,7 +808,7 @@ void output_flex_t::call_lua_function(prepared_lua_function_t func,
 {
     m_calling_context = func.context();
 
-    lua_pushvalue(lua_state(), func.index()); // the function to call
+    lua_pushvalue(lua_state(), func.index());          // the function to call
     push_osm_object_to_lua_stack(lua_state(), object); // the single argument
 
     luaX_set_context(lua_state(), this);
@@ -886,7 +836,7 @@ void output_flex_t::get_mutex_and_call_lua_function(
 
 void output_flex_t::pending_way(osmid_t id)
 {
-    if (!m_process_way) {
+    if (!m_process_way && !m_process_untagged_way) {
         return;
     }
 
@@ -895,56 +845,11 @@ void output_flex_t::pending_way(osmid_t id)
     }
 
     way_delete(id);
-
-    get_mutex_and_call_lua_function(m_process_way, m_way_cache.get());
-}
-
-/**
- * Expects a Lua (hash) table on the stack, reads the field with name of the
- * 'type' parameter which must be either nil or a Lua (array) table, in which
- * case all (integer) ids in that table are reads into the 'ids' out
- * parameter.
- */
-void get_object_ids(lua_State *lua_state, char const *const type, idlist_t *ids)
-{
-    lua_getfield(lua_state, -1, type);
-    int const ltype = lua_type(lua_state, -1);
-
-    if (ltype == LUA_TNIL) {
-        lua_pop(lua_state, 1);
-        return;
+    auto const &func = m_way_cache.get().tags().empty() ? m_process_untagged_way
+                                                        : m_process_way;
+    if (func) {
+        get_mutex_and_call_lua_function(func, m_way_cache.get());
     }
-
-    if (ltype != LUA_TTABLE) {
-        lua_pop(lua_state, 1);
-        throw fmt_error(
-            "Table returned from select_relation_members() contains '{}' "
-            "field, but it isn't an array table.",
-            type);
-    }
-
-    if (!luaX_is_array(lua_state)) {
-        lua_pop(lua_state, 1);
-        throw fmt_error(
-            "Table returned from select_relation_members() contains '{}' "
-            "field, but it isn't an array table.",
-            type);
-    }
-
-    luaX_for_each(lua_state, [&]() {
-        osmid_t const id = lua_tointeger(lua_state, -1);
-        if (id == 0) {
-            throw fmt_error(
-                "Table returned from select_relation_members() contains "
-                "'{}' field, which must contain an array of non-zero "
-                "integer node ids.",
-                type);
-        }
-
-        ids->push_back(id);
-    });
-
-    lua_pop(lua_state, 1);
 }
 
 void output_flex_t::select_relation_members()
@@ -991,9 +896,20 @@ void output_flex_t::select_relation_members(osmid_t id)
     select_relation_members();
 }
 
+void output_flex_t::process_relation()
+{
+    auto const &func = m_relation_cache.get().tags().empty()
+                           ? m_process_untagged_relation
+                           : m_process_relation;
+    if (func) {
+        get_mutex_and_call_lua_function(func, m_relation_cache.get());
+    }
+}
+
 void output_flex_t::pending_relation(osmid_t id)
 {
-    if (!m_process_relation && !m_select_relation_members) {
+    if (!m_process_relation && !m_process_untagged_relation &&
+        !m_select_relation_members) {
         return;
     }
 
@@ -1003,16 +919,12 @@ void output_flex_t::pending_relation(osmid_t id)
 
     select_relation_members();
     delete_from_tables(osmium::item_type::relation, id);
-
-    if (m_process_relation) {
-        get_mutex_and_call_lua_function(m_process_relation,
-                                        m_relation_cache.get());
-    }
+    process_relation();
 }
 
 void output_flex_t::pending_relation_stage1c(osmid_t id)
 {
-    if (!m_process_relation) {
+    if (!m_process_relation && !m_process_untagged_relation) {
         return;
     }
 
@@ -1021,7 +933,7 @@ void output_flex_t::pending_relation_stage1c(osmid_t id)
     }
 
     m_disable_insert = true;
-    get_mutex_and_call_lua_function(m_process_relation, m_relation_cache.get());
+    process_relation();
     m_disable_insert = false;
 }
 
@@ -1186,6 +1098,38 @@ void output_flex_t::delete_from_tables(osmium::item_type type, osmid_t osm_id)
     }
 }
 
+void output_flex_t::node_delete(osmium::Node const &node)
+{
+    if (m_process_deleted_node) {
+        m_context_node = &node;
+        get_mutex_and_call_lua_function(m_process_deleted_node, node);
+        m_context_node = nullptr;
+    }
+
+    node_delete(node.id());
+}
+
+void output_flex_t::way_delete(osmium::Way *way)
+{
+    if (m_process_deleted_way) {
+        m_way_cache.init(way);
+        get_mutex_and_call_lua_function(m_process_deleted_way,
+                                        m_way_cache.get());
+    }
+
+    way_delete(way->id());
+}
+
+void output_flex_t::relation_delete(osmium::Relation const &rel)
+{
+    if (m_process_deleted_relation) {
+        m_relation_cache.init(rel);
+        get_mutex_and_call_lua_function(m_process_deleted_relation, rel);
+    }
+
+    relation_delete(rel.id());
+}
+
 /* Delete is easy, just remove all traces of this object. We don't need to
  * worry about finding objects that depend on it, since the same diff must
  * contain the change for that also. */
@@ -1228,13 +1172,17 @@ void output_flex_t::start()
     for (auto &table : m_table_connections) {
         table.start(m_db_connection, get_options()->append);
     }
+
+    for (auto &locator : *m_locators) {
+        locator.build_index();
+    }
 }
 
 output_flex_t::output_flex_t(output_flex_t const *other,
                              std::shared_ptr<middle_query_t> mid,
                              std::shared_ptr<db_copy_thread_t> copy_thread)
-: output_t(other, std::move(mid)), m_tables(other->m_tables),
-  m_expire_outputs(other->m_expire_outputs),
+: output_t(other, std::move(mid)), m_locators(other->m_locators),
+  m_tables(other->m_tables), m_expire_outputs(other->m_expire_outputs),
   m_db_connection(get_options()->connection_params, "out.flex.thread"),
   m_stage2_way_ids(other->m_stage2_way_ids),
   m_copy_thread(std::move(copy_thread)), m_lua_state(other->m_lua_state),
@@ -1244,6 +1192,9 @@ output_flex_t::output_flex_t(output_flex_t const *other,
   m_process_untagged_node(other->m_process_untagged_node),
   m_process_untagged_way(other->m_process_untagged_way),
   m_process_untagged_relation(other->m_process_untagged_relation),
+  m_process_deleted_node(other->m_process_deleted_node),
+  m_process_deleted_way(other->m_process_deleted_way),
+  m_process_deleted_relation(other->m_process_deleted_relation),
   m_select_relation_members(other->m_select_relation_members),
   m_after_nodes(other->m_after_nodes), m_after_ways(other->m_after_ways),
   m_after_relations(other->m_after_relations)
@@ -1254,8 +1205,9 @@ output_flex_t::output_flex_t(output_flex_t const *other,
     }
 
     for (auto &expire_output : *m_expire_outputs) {
-        m_expire_tiles.emplace_back(expire_output.maxzoom(),
-                                    reprojection::create_projection(3857));
+        m_expire_tiles.emplace_back(
+            expire_output.maxzoom(),
+            reprojection_t::create_projection(PROJ_SPHERE_MERC));
     }
 }
 
@@ -1298,7 +1250,8 @@ output_flex_t::output_flex_t(std::shared_ptr<middle_query_t> const &mid,
         eo.set_maxzoom(options.expire_tiles_zoom);
 
         for (auto &table : *m_tables) {
-            if (table.has_geom_column() && table.geom_column().srid() == 3857) {
+            if (table.has_geom_column() &&
+                table.geom_column().srid() == PROJ_SPHERE_MERC) {
                 expire_config_t config{};
                 config.expire_output = m_expire_outputs->size() - 1;
                 if (options.expire_tiles_max_bbox > 0.0) {
@@ -1317,77 +1270,15 @@ output_flex_t::output_flex_t(std::shared_ptr<middle_query_t> const &mid,
         m_table_connections.emplace_back(&table, m_copy_thread);
     }
 
-    for (auto &expire_output : *m_expire_outputs) {
-        m_expire_tiles.emplace_back(expire_output.maxzoom(),
-                                    reprojection::create_projection(3857));
+    for (auto const &expire_output : *m_expire_outputs) {
+        m_expire_tiles.emplace_back(
+            expire_output.maxzoom(),
+            reprojection_t::create_projection(PROJ_SPHERE_MERC));
     }
 
     create_expire_tables(*m_expire_outputs, get_options()->connection_params);
 }
 
-namespace {
-
-/**
- * Define the osm2pgsql.Table class/metatable.
- */
-void init_table_class(lua_State *lua_state)
-{
-    lua_getglobal(lua_state, "osm2pgsql");
-    if (luaL_newmetatable(lua_state, osm2pgsql_table_name) != 1) {
-        throw std::runtime_error{"Internal error: Lua newmetatable failed."};
-    }
-    lua_pushvalue(lua_state, -1); // Copy of new metatable
-
-    // Add metatable as osm2pgsql.Table so we can access it from Lua
-    lua_setfield(lua_state, -3, "Table");
-
-    // Now add functions to metatable
-    lua_pushvalue(lua_state, -1);
-    lua_setfield(lua_state, -2, "__index");
-    luaX_add_table_func(lua_state, "__tostring", lua_trampoline_table_tostring);
-    luaX_add_table_func(lua_state, "insert", lua_trampoline_table_insert);
-    luaX_add_table_func(lua_state, "name", lua_trampoline_table_name);
-    luaX_add_table_func(lua_state, "schema", lua_trampoline_table_schema);
-    luaX_add_table_func(lua_state, "cluster", lua_trampoline_table_cluster);
-    luaX_add_table_func(lua_state, "columns", lua_trampoline_table_columns);
-
-    lua_pop(lua_state, 2);
-}
-
-/**
- * Define the osm2pgsql.ExpireOutput class/metatable.
- */
-void init_expire_output_class(lua_State *lua_state)
-{
-    lua_getglobal(lua_state, "osm2pgsql");
-    if (luaL_newmetatable(lua_state, osm2pgsql_expire_output_name) != 1) {
-        throw std::runtime_error{"Internal error: Lua newmetatable failed."};
-    }
-    lua_pushvalue(lua_state, -1); // Copy of new metatable
-
-    // Add metatable as osm2pgsql.ExpireOutput so we can access it from Lua
-    lua_setfield(lua_state, -3, "ExpireOutput");
-
-    // Now add functions to metatable
-    lua_pushvalue(lua_state, -1);
-    lua_setfield(lua_state, -2, "__index");
-    luaX_add_table_func(lua_state, "__tostring",
-                        lua_trampoline_expire_output_tostring);
-    luaX_add_table_func(lua_state, "minzoom",
-                        lua_trampoline_expire_output_minzoom);
-    luaX_add_table_func(lua_state, "maxzoom",
-                        lua_trampoline_expire_output_maxzoom);
-    luaX_add_table_func(lua_state, "filename",
-                        lua_trampoline_expire_output_filename);
-    luaX_add_table_func(lua_state, "schema",
-                        lua_trampoline_expire_output_schema);
-    luaX_add_table_func(lua_state, "table", lua_trampoline_expire_output_table);
-
-    lua_pop(lua_state, 2);
-}
-
-} // anonymous namespace
-
 void output_flex_t::init_lua(std::string const &filename,
                              properties_t const &properties)
 {
@@ -1402,18 +1293,22 @@ void output_flex_t::init_lua(std::string const &filename,
     lua_createtable(lua_state(), 0, (int)properties.size());
     for (auto const &property : properties) {
         luaX_add_table_str(lua_state(), property.first.c_str(),
-                           property.second.c_str());
+                           property.second);
     }
     lua_rawset(lua_state(), -3);
 
+    luaX_add_table_func(lua_state(), "define_locator",
+                        lua_trampoline_app_define_locator);
+
     luaX_add_table_func(lua_state(), "define_table",
                         lua_trampoline_app_define_table);
 
     luaX_add_table_func(lua_state(), "define_expire_output",
                         lua_trampoline_app_define_expire_output);
 
-    init_table_class(lua_state());
-    init_expire_output_class(lua_state());
+    lua_wrapper_expire_output_t::init(lua_state());
+    lua_wrapper_locator_t::init(lua_state(), get_options()->connection_params);
+    lua_wrapper_table_t::init(lua_state());
 
     // Clean up stack
     lua_settop(lua_state(), 0);
@@ -1422,45 +1317,23 @@ void output_flex_t::init_lua(std::string const &filename,
 
     assert(lua_gettop(lua_state()) == 0);
 
+    luaX_set_up_metatable(
+        lua_state(), "OSMObject", OSM2PGSQL_OSMOBJECT_CLASS,
+        {{"get_bbox", lua_trampoline_app_get_bbox},
+         {"as_linestring", lua_trampoline_app_as_linestring},
+         {"as_point", lua_trampoline_app_as_point},
+         {"as_polygon", lua_trampoline_app_as_polygon},
+         {"as_multipoint", lua_trampoline_app_as_multipoint},
+         {"as_multilinestring", lua_trampoline_app_as_multilinestring},
+         {"as_multipolygon", lua_trampoline_app_as_multipolygon},
+         {"as_geometrycollection", lua_trampoline_app_as_geometrycollection}});
+
     // Load compiled in init.lua
     if (luaL_dostring(lua_state(), lua_init())) {
         throw fmt_error("Internal error in Lua setup: {}.",
                         lua_tostring(lua_state(), -1));
     }
 
-    // Store the methods on OSM objects in its metatable.
-    lua_getglobal(lua_state(), "object_metatable");
-    luaX_pushstring(lua_state(), osm2pgsql_object_metatable);
-    lua_setfield(lua_state(), -2, "__name");
-    lua_getfield(lua_state(), -1, "__index");
-    luaX_add_table_func(lua_state(), "get_bbox", lua_trampoline_app_get_bbox);
-    luaX_add_table_func(lua_state(), "as_linestring",
-                        lua_trampoline_app_as_linestring);
-    luaX_add_table_func(lua_state(), "as_point",
-                        lua_trampoline_app_as_point);
-    luaX_add_table_func(lua_state(), "as_polygon",
-                        lua_trampoline_app_as_polygon);
-    luaX_add_table_func(lua_state(), "as_multipoint",
-                        lua_trampoline_app_as_multipoint);
-    luaX_add_table_func(lua_state(), "as_multilinestring",
-                        lua_trampoline_app_as_multilinestring);
-    luaX_add_table_func(lua_state(), "as_multipolygon",
-                        lua_trampoline_app_as_multipolygon);
-    luaX_add_table_func(lua_state(), "as_geometrycollection",
-                        lua_trampoline_app_as_geometrycollection);
-    lua_settop(lua_state(), 0);
-
-    // Store the global object "object_metatable" defined in the init.lua
-    // script in the registry and then remove the global object. It will
-    // later be used as metatable for OSM objects.
-    luaX_pushstring(lua_state(), osm2pgsql_object_metatable);
-    lua_getglobal(lua_state(), "object_metatable");
-    lua_settable(lua_state(), LUA_REGISTRYINDEX);
-    lua_pushnil(lua_state());
-    lua_setglobal(lua_state(), "object_metatable");
-
-    assert(lua_gettop(lua_state()) == 0);
-
     // Load user config file
     luaX_set_context(lua_state(), this);
     if (luaL_dofile(lua_state(), filename.c_str())) {
@@ -1487,6 +1360,14 @@ void output_flex_t::init_lua(std::string const &filename,
         prepared_lua_function_t{lua_state(), calling_context::process_relation,
                                 "process_untagged_relation"};
 
+    m_process_deleted_node = prepared_lua_function_t{
+        lua_state(), calling_context::process_node, "process_deleted_node"};
+    m_process_deleted_way = prepared_lua_function_t{
+        lua_state(), calling_context::process_way, "process_deleted_way"};
+    m_process_deleted_relation =
+        prepared_lua_function_t{lua_state(), calling_context::process_relation,
+                                "process_deleted_relation"};
+
     m_select_relation_members = prepared_lua_function_t{
         lua_state(), calling_context::select_relation_members,
         "select_relation_members", 1};
