@@ -17,6 +17,7 @@
 #include "flex-table.hpp"
 #include "geom.hpp"
 #include "idlist.hpp"
+#include "locator.hpp"
 #include "output.hpp"
 
 #include <osmium/osm/item_type.hpp>
@@ -39,12 +40,12 @@ struct options_t;
  * When C++ code is called from the Lua code we sometimes need to know
  * in what context this happens. These are the possible contexts.
  */
-enum class calling_context
+enum class calling_context : std::uint8_t
 {
     main = 0, ///< In main context, i.e. the Lua script outside any callbacks
-    process_node = 1, ///< In the process_node() callback
-    process_way = 2, ///< In the process_way() callback
-    process_relation = 3, ///< In the process_relation() callback
+    process_node = 1,     ///< Inside a callback where a node is handled
+    process_way = 2,      ///< Inside a callback where a way is handled
+    process_relation = 3, ///< Inside a callback where a relation is handled
     select_relation_members = 4 ///< In the select_relation_members() callback
 };
 
@@ -75,7 +76,7 @@ public:
     int index() const noexcept { return m_index; }
 
     /// The name of the function.
-    char const* name() const noexcept { return m_name; }
+    char const *name() const noexcept { return m_name; }
 
     /// The number of results this function is expected to have.
     int nresults() const noexcept { return m_nresults; }
@@ -146,9 +147,9 @@ public:
     void way_modify(osmium::Way *way) override;
     void relation_modify(osmium::Relation const &rel) override;
 
-    void node_delete(osmid_t id) override;
-    void way_delete(osmid_t id) override;
-    void relation_delete(osmid_t id) override;
+    void node_delete(osmium::Node const &node) override;
+    void way_delete(osmium::Way *way) override;
+    void relation_delete(osmium::Relation const &rel) override;
 
     void merge_expire_trees(output_t *other) override;
 
@@ -160,24 +161,21 @@ public:
     int app_as_multipolygon();
     int app_as_geometrycollection();
 
+    int app_define_locator();
     int app_define_table();
     int app_define_expire_output();
     int app_get_bbox();
 
-    int table_tostring();
     int table_insert();
-    int table_name();
-    int table_schema();
-    int table_cluster();
-    int table_columns();
 
-    int expire_output_tostring();
-    int expire_output_name();
-    int expire_output_minzoom();
-    int expire_output_maxzoom();
-    int expire_output_filename();
-    int expire_output_schema();
-    int expire_output_table();
+    // Get the flex table that is as first parameter on the Lua stack.
+    flex_table_t &get_table_from_param();
+
+    // Get the expire output that is as first parameter on the Lua stack.
+    expire_output_t &get_expire_output_from_param();
+
+    // Get the flex locator that is as first parameter on the Lua stack.
+    locator_t &get_locator_from_param();
 
 private:
     void select_relation_members();
@@ -198,20 +196,20 @@ private:
     void get_mutex_and_call_lua_function(prepared_lua_function_t func,
                                          osmium::OSMObject const &object);
 
+    void process_relation();
+
     void init_lua(std::string const &filename, properties_t const &properties);
 
-    // Get the flex table that is as first parameter on the Lua stack.
-    flex_table_t const &get_table_from_param();
-
-    // Get the expire output that is as first parameter on the Lua stack.
-    expire_output_t const &get_expire_output_from_param();
-
     void check_context_and_state(char const *name, char const *context,
                                  bool condition);
 
     osmium::OSMObject const &
     check_and_get_context_object(flex_table_t const &table);
 
+    void node_delete(osmid_t id);
+    void way_delete(osmid_t id);
+    void relation_delete(osmid_t id);
+
     void delete_from_table(table_connection_t *table_connection,
                            pg_conn_t const &db_connection,
                            osmium::item_type type, osmid_t osm_id);
@@ -249,10 +247,7 @@ private:
          */
         bool add_members(middle_query_t const &middle);
 
-        osmium::Relation const &get() const noexcept
-        {
-            return *m_relation;
-        }
+        osmium::Relation const &get() const noexcept { return *m_relation; }
 
         osmium::memory::Buffer const &members_buffer() const noexcept
         {
@@ -271,6 +266,9 @@ private:
 
     }; // relation_cache_t
 
+    std::shared_ptr<std::vector<locator_t>> m_locators =
+        std::make_shared<std::vector<locator_t>>();
+
     std::shared_ptr<std::vector<flex_table_t>> m_tables =
         std::make_shared<std::vector<flex_table_t>>();
 
@@ -293,7 +291,7 @@ private:
     // accessed while protected using the lua_mutex.
     std::shared_ptr<lua_State> m_lua_state;
 
-    std::vector<expire_tiles> m_expire_tiles;
+    std::vector<expire_tiles_t> m_expire_tiles;
 
     way_cache_t m_way_cache;
     relation_cache_t m_relation_cache;
@@ -309,6 +307,10 @@ private:
     prepared_lua_function_t m_process_untagged_way;
     prepared_lua_function_t m_process_untagged_relation;
 
+    prepared_lua_function_t m_process_deleted_node;
+    prepared_lua_function_t m_process_deleted_way;
+    prepared_lua_function_t m_process_deleted_relation;
+
     prepared_lua_function_t m_select_relation_members;
 
     prepared_lua_function_t m_after_nodes;
@@ -324,4 +326,6 @@ private:
     bool m_disable_insert = false;
 };
 
+int lua_trampoline_table_insert(lua_State *lua_state);
+
 #endif // OSM2PGSQL_OUTPUT_FLEX_HPP
