@@ -38,6 +38,7 @@
 #include "osmtypes.hpp"
 #include "output-pgsql.hpp"
 #include "pgsql.hpp"
+#include "projection.hpp"
 #include "reprojection.hpp"
 #include "taginfo-impl.hpp"
 #include "tagtransform.hpp"
@@ -51,7 +52,7 @@ double calculate_area(bool reproject_area, geom::geometry_t const &geom4326,
                       geom::geometry_t const &projected_geom)
 {
     static thread_local auto const proj3857 =
-        reprojection::create_projection(3857);
+        reprojection_t::create_projection(PROJ_SPHERE_MERC);
 
     if (reproject_area) {
         auto const ogeom = geom::transform(geom4326, *proj3857);
@@ -104,7 +105,7 @@ void output_pgsql_t::pgsql_out_way(osmium::Way const &way, taglist_t *tags,
             if (m_enable_way_area) {
                 double const area = calculate_area(
                     get_options()->reproject_area, geom, projected_geom);
-                util::double_to_buffer const tmp{area};
+                util::double_to_buffer_t const tmp{area};
                 tags->set("way_area", tmp.c_str());
             }
             m_tables[t_poly]->write_row(way.id(), *tags, wkb);
@@ -206,6 +207,10 @@ void output_pgsql_t::wait()
 
 void output_pgsql_t::node_add(osmium::Node const &node)
 {
+    if (m_ignore_untagged_objects && node.tags().empty()) {
+        return;
+    }
+
     taglist_t outtags;
     if (m_tagtransform->filter_tags(node, nullptr, nullptr, &outtags)) {
         return;
@@ -219,6 +224,10 @@ void output_pgsql_t::node_add(osmium::Node const &node)
 
 void output_pgsql_t::way_add(osmium::Way *way)
 {
+    if (m_ignore_untagged_objects && way->tags().empty()) {
+        return;
+    }
+
     bool polygon = false;
     bool roads = false;
     taglist_t outtags;
@@ -307,7 +316,7 @@ void output_pgsql_t::pgsql_process_relation(osmium::Relation const &rel)
             if (m_enable_way_area) {
                 double const area = calculate_area(
                     get_options()->reproject_area, sgeom, projected_geom);
-                util::double_to_buffer const tmp{area};
+                util::double_to_buffer_t const tmp{area};
                 outtags.set("way_area", tmp.c_str());
             }
             m_tables[t_poly]->write_row(-rel.id(), outtags, wkb);
@@ -317,6 +326,10 @@ void output_pgsql_t::pgsql_process_relation(osmium::Relation const &rel)
 
 void output_pgsql_t::relation_add(osmium::Relation const &rel)
 {
+    if (m_ignore_untagged_objects && rel.tags().empty()) {
+        return;
+    }
+
     char const *const type = rel.tags()["type"];
 
     /* Must have a type field or we ignore it */
@@ -337,15 +350,15 @@ void output_pgsql_t::relation_add(osmium::Relation const &rel)
 /* Delete is easy, just remove all traces of this object. We don't need to
  * worry about finding objects that depend on it, since the same diff must
  * contain the change for that also. */
-void output_pgsql_t::node_delete(osmid_t osm_id)
+void output_pgsql_t::node_delete(osmium::Node const &node)
 {
     if (m_expire.enabled()) {
-        auto const results = m_tables[t_point]->get_wkb(osm_id);
+        auto const results = m_tables[t_point]->get_wkb(node.id());
         if (expire_from_result(&m_expire, results, m_expire_config) != 0) {
-            m_tables[t_point]->delete_row(osm_id);
+            m_tables[t_point]->delete_row(node.id());
         }
     } else {
-        m_tables[t_point]->delete_row(osm_id);
+        m_tables[t_point]->delete_row(node.id());
     }
 }
 
@@ -353,7 +366,7 @@ void output_pgsql_t::delete_from_output_and_expire(osmid_t id)
 {
     m_tables[t_roads]->delete_row(id);
 
-    for (auto table : {t_line, t_poly}) {
+    for (auto const table : {t_line, t_poly}) {
         if (m_expire.enabled()) {
             auto const results = m_tables.at(table)->get_wkb(id);
             if (expire_from_result(&m_expire, results, m_expire_config) != 0) {
@@ -380,9 +393,9 @@ void output_pgsql_t::pgsql_delete_way_from_output(osmid_t osm_id)
     delete_from_output_and_expire(osm_id);
 }
 
-void output_pgsql_t::way_delete(osmid_t osm_id)
+void output_pgsql_t::way_delete(osmium::Way *way)
 {
-    pgsql_delete_way_from_output(osm_id);
+    pgsql_delete_way_from_output(way->id());
 }
 
 /* Relations are identified by using negative IDs */
@@ -391,9 +404,9 @@ void output_pgsql_t::pgsql_delete_relation_from_output(osmid_t osm_id)
     delete_from_output_and_expire(-osm_id);
 }
 
-void output_pgsql_t::relation_delete(osmid_t osm_id)
+void output_pgsql_t::relation_delete(osmium::Relation const &rel)
 {
-    pgsql_delete_relation_from_output(osm_id);
+    pgsql_delete_relation_from_output(rel.id());
 }
 
 /* Modify is slightly trickier. The basic idea is we simply delete the
@@ -401,19 +414,19 @@ void output_pgsql_t::relation_delete(osmid_t osm_id)
  * objects that depend on this one */
 void output_pgsql_t::node_modify(osmium::Node const &node)
 {
-    node_delete(node.id());
+    node_delete(node);
     node_add(node);
 }
 
 void output_pgsql_t::way_modify(osmium::Way *way)
 {
-    way_delete(way->id());
+    way_delete(way);
     way_add(way);
 }
 
 void output_pgsql_t::relation_modify(osmium::Relation const &rel)
 {
-    relation_delete(rel.id());
+    relation_delete(rel);
     relation_add(rel);
 }
 
@@ -436,7 +449,9 @@ std::shared_ptr<output_t> output_pgsql_t::clone(
 output_pgsql_t::output_pgsql_t(std::shared_ptr<middle_query_t> const &mid,
                                std::shared_ptr<thread_pool_t> thread_pool,
                                options_t const &options)
-: output_t(mid, std::move(thread_pool), options), m_proj(options.projection),
+: output_t(mid, std::move(thread_pool), options),
+  m_ignore_untagged_objects(!options.extra_attributes),
+  m_proj(options.projection),
   m_expire(options.expire_tiles_zoom, options.projection),
   m_buffer(32768, osmium::memory::Buffer::auto_grow::yes),
   m_rels_buffer(1024, osmium::memory::Buffer::auto_grow::yes),
@@ -454,7 +469,7 @@ output_pgsql_t::output_pgsql_t(std::shared_ptr<middle_query_t> const &mid,
     log_debug("Using projection SRS {} ({})", options.projection->target_srs(),
               options.projection->target_desc());
 
-    export_list exlist;
+    export_list_t exlist;
 
     m_enable_way_area = read_style_file(options.style, &exlist);
 
@@ -507,6 +522,7 @@ output_pgsql_t::output_pgsql_t(
     std::shared_ptr<db_copy_thread_t> const &copy_thread)
 : output_t(other, mid), m_tagtransform(other->m_tagtransform->clone()),
   m_enable_way_area(other->m_enable_way_area),
+  m_ignore_untagged_objects(other->m_ignore_untagged_objects),
   m_proj(get_options()->projection), m_expire_config(other->m_expire_config),
   m_expire(get_options()->expire_tiles_zoom, get_options()->projection),
   m_buffer(1024, osmium::memory::Buffer::auto_grow::yes),
