@@ -20,8 +20,8 @@ namespace {
 
 database_capabilities_t &capabilities() noexcept
 {
-    static database_capabilities_t c;
-    return c;
+    static database_capabilities_t capabilities;
+    return capabilities;
 }
 
 } // anonymous namespace
@@ -71,6 +71,19 @@ void init_database_name(pg_conn_t const &db_connection)
     capabilities().database_name = res.get(0, 0);
 }
 
+void init_geometry_oid(pg_conn_t const &db_connection)
+{
+    auto const res =
+        db_connection.exec("SELECT oid FROM pg_type WHERE typname='geometry'");
+
+    if (res.num_tuples() != 1) {
+        throw std::runtime_error{"Database error: Can not get geometry type. "
+                                 "Is PostGIS extension loaded?"};
+    }
+
+    capabilities().geometry_type_oid = std::stoul(std::string{res.get(0, 0)});
+}
+
 void init_postgis_version(pg_conn_t const &db_connection)
 {
     auto const res = db_connection.exec(
@@ -85,8 +98,15 @@ void init_postgis_version(pg_conn_t const &db_connection)
             capabilities().database_name);
     }
 
-    capabilities().postgis = {std::stoi(std::string{res.get(0, 0)}),
-                              std::stoi(std::string{res.get(1, 0)})};
+    try {
+        if (res.num_tuples() >= 2) {
+            capabilities().postgis = {std::stoi(std::string{res.get(0, 0)}),
+                                      std::stoi(std::string{res.get(1, 0)})};
+        }
+    } catch (...) { // NOLINT(bugprone-empty-catch)
+        // Fall through if std::stoi() fails in which case the version
+        // is reported as 0.
+    }
 }
 
 } // anonymous namespace
@@ -96,12 +116,18 @@ void init_database_capabilities(pg_conn_t const &db_connection)
     init_settings(db_connection);
     init_database_name(db_connection);
     init_postgis_version(db_connection);
+    init_geometry_oid(db_connection);
 
     try {
         log_info("Database version: {}",
                  capabilities().settings.at("server_version"));
-        log_info("PostGIS version: {}.{}", capabilities().postgis.major,
-                 capabilities().postgis.minor);
+
+        if (capabilities().postgis.major == 0) {
+            log_info("PostGIS version: could not be detected");
+        } else {
+            log_info("PostGIS version: {}.{}", capabilities().postgis.major,
+                     capabilities().postgis.minor);
+        }
 
         auto const version_str =
             capabilities().settings.at("server_version_num");
@@ -173,6 +199,11 @@ bool has_table(std::string schema, std::string const &name)
     return capabilities().tables.count(schema);
 }
 
+bool is_geometry_type(unsigned int oid)
+{
+    return capabilities().geometry_type_oid == oid;
+}
+
 void check_schema(std::string const &schema)
 {
     if (has_schema(schema)) {
