@@ -22,8 +22,8 @@
 
 std::size_t pg_result_t::affected_rows() const noexcept
 {
-    char const *const s = PQcmdTuples(m_result.get());
-    return std::strtoull(s, nullptr, 10);
+    char const *const rows_as_string = PQcmdTuples(m_result.get());
+    return std::strtoull(rows_as_string, nullptr, 10);
 }
 
 std::atomic<std::uint32_t> pg_conn_t::connection_id{0};
@@ -136,12 +136,12 @@ pg_result_t pg_conn_t::exec(std::string const &sql) const
     return exec(sql.c_str());
 }
 
-void pg_conn_t::copy_start(std::string_view sql) const
+void pg_conn_t::copy_start(std::string const &sql) const
 {
     assert(m_conn);
 
     log_sql("(C{}) {}", m_connection_id, sql);
-    pg_result_t const res{PQexec(m_conn.get(), sql.data())};
+    pg_result_t const res{PQexec(m_conn.get(), sql.c_str())};
     if (res.status() != PGRES_COPY_IN) {
         throw fmt_error("Database error on COPY: {}", error_msg());
     }
@@ -153,9 +153,10 @@ void pg_conn_t::copy_send(std::string_view data, std::string_view context) const
 
     log_sql_data("(C{}) Copy data to '{}':\n{}", m_connection_id, context,
                  data);
-    int const r = PQputCopyData(m_conn.get(), data.data(), (int)data.size());
+    int const result =
+        PQputCopyData(m_conn.get(), data.data(), (int)data.size());
 
-    switch (r) {
+    switch (result) {
     case 0: // need to wait for write ready
         log_error("{} - COPY unexpectedly busy", context);
         break;
@@ -194,15 +195,15 @@ void pg_conn_t::copy_end(std::string_view context) const
     }
 }
 
-void pg_conn_t::prepare_internal(std::string_view stmt,
-                                 std::string_view sql) const
+void pg_conn_t::prepare_internal(std::string const &stmt,
+                                 std::string const &sql) const
 {
     if (get_logger().log_sql()) {
         log_sql("(C{}) PREPARE {} AS {}", m_connection_id, stmt, sql);
     }
 
     pg_result_t const res{
-        PQprepare(m_conn.get(), stmt.data(), sql.data(), 0, nullptr)};
+        PQprepare(m_conn.get(), stmt.c_str(), sql.c_str(), 0, nullptr)};
     if (res.status() != PGRES_COMMAND_OK) {
         throw fmt_error("Prepare failed for '{}': {}.", sql, error_msg());
     }
