@@ -26,7 +26,7 @@ struct layers_type
     bool roads;
 };
 
-constexpr std::array<layers_type, 25> const layers = {
+constexpr std::array<layers_type, 25> LAYERS = {
     {{"proposed", 1, false},       {"construction", 2, false},
      {"steps", 10, false},         {"cycleway", 10, false},
      {"bridleway", 10, false},     {"footway", 10, false},
@@ -60,7 +60,7 @@ void add_z_order(taglist_t *tags, bool *roads)
     *roads = false;
 
     if (highway) {
-        for (auto const &layer : layers) {
+        for (auto const &layer : LAYERS) {
             if (*highway == layer.highway) {
                 z_order += layer.offset;
                 *roads = layer.roads;
@@ -96,7 +96,8 @@ bool starts_with(char const *input, std::string const &test) noexcept
 
 } // anonymous namespace
 
-c_tagtransform_t::c_tagtransform_t(options_t const *options, export_list exlist)
+c_tagtransform_t::c_tagtransform_t(options_t const *options,
+                                   export_list_t exlist)
 : m_options(options), m_export_list(std::move(exlist))
 {}
 
@@ -112,7 +113,7 @@ bool c_tagtransform_t::check_key(std::vector<taginfo> const &infos,
     //go through the actual tags found on the item and keep the ones in the export list
     for (auto const &info : infos) {
         if (info.flags & FLAG_DELETE) {
-            if (wildMatch(info.name.c_str(), k)) {
+            if (wild_match(info.name.c_str(), k)) {
                 return false;
             }
         } else if (std::strcmp(info.name.c_str(), k) == 0) {
@@ -220,10 +221,12 @@ bool c_tagtransform_t::filter_tags(osmium::OSMObject const &o, bool *polygon,
     return filter;
 }
 
-bool c_tagtransform_t::filter_rel_member_tags(
-    taglist_t const &rel_tags, osmium::memory::Buffer const &,
-    rolelist_t const &, bool *make_boundary, bool *make_polygon, bool *roads,
-    taglist_t *out_tags)
+bool c_tagtransform_t::filter_rel_member_tags(taglist_t const &rel_tags,
+                                              osmium::memory::Buffer const &,
+                                              rolelist_t const &,
+                                              bool *make_boundary,
+                                              bool *make_polygon, bool *roads,
+                                              taglist_t *out_tags)
 {
     std::string const *type = rel_tags.get("type");
     if (!type) {
