@@ -9,7 +9,8 @@
 
 #include "template.hpp"
 
-void template_t::set_params(params_t const &params) {
+void template_t::set_params(params_t const &params)
+{
     for (auto const &[key, value] : params) {
         m_format_store.push_back(fmt::arg(key.c_str(), to_string(value)));
     }
