@@ -195,10 +195,10 @@ void write_collection(std::string *data, geom::collection_t const &geom,
     }
 }
 
-class make_ewkb_visitor
+class make_ewkb_visitor_t
 {
 public:
-    make_ewkb_visitor(uint32_t srid, bool ensure_multi) noexcept
+    make_ewkb_visitor_t(uint32_t srid, bool ensure_multi) noexcept
     : m_srid(srid), m_ensure_multi(ensure_multi)
     {}
 
@@ -217,10 +217,10 @@ public:
             write_point(&data, geom);
         } else {
             // 9 byte header plus one set of coordinates
-            constexpr const std::size_t size = 9 + 2 * 8;
-            data.reserve(size);
+            constexpr std::size_t SIZE = 9 + 2 * 8;
+            data.reserve(SIZE);
             write_point(&data, geom, m_srid);
-            assert(data.size() == size);
+            assert(data.size() == SIZE);
         }
 
         return data;
@@ -292,7 +292,7 @@ private:
     uint32_t m_srid;
     bool m_ensure_multi;
 
-}; // class make_ewkb_visitor
+}; // class make_ewkb_visitor_t
 
 /**
  * Parser for (E)WKB.
@@ -560,7 +560,7 @@ private:
 
 std::string geom_to_ewkb(geom::geometry_t const &geom, bool ensure_multi)
 {
-    return geom.visit(ewkb::make_ewkb_visitor{
+    return geom.visit(ewkb::make_ewkb_visitor_t{
         static_cast<uint32_t>(geom.srid()), ensure_multi});
 }
 
@@ -575,42 +575,3 @@ geom::geometry_t ewkb_to_geom(std::string_view wkb)
 
     return geom;
 }
-
-namespace {
-
-constexpr std::array<char, 256> const hex_table = {
-    0, 0, 0, 0,   0, 0, 0, 0,   0, 0, 0, 0,   0, 0, 0, 0,
-    0, 0, 0, 0,   0, 0, 0, 0,   0, 0, 0, 0,   0, 0, 0, 0,
-    0, 0, 0, 0,   0, 0, 0, 0,   0, 0, 0, 0,   0, 0, 0, 0,
-    0, 1, 2, 3,   4, 5, 6, 7,   8, 9, 0, 0,   0, 0, 0, 0,
-
-    0, 10, 11, 12,   13, 14, 15, 0,   0, 0, 0, 0,   0, 0, 0, 0,
-    0,  0,  0,  0,    0,  0,  0, 0,   0, 0, 0, 0,   0, 0, 0, 0,
-    0, 10, 11, 12,   13, 14, 15, 0,   0, 0, 0, 0,   0, 0, 0, 0,
-};
-
-} // anonymous namespace
-
-unsigned char decode_hex_char(char c) noexcept
-{
-    // NOLINTNEXTLINE(cppcoreguidelines-pro-bounds-constant-array-index)
-    return hex_table[static_cast<std::size_t>(static_cast<unsigned char>(c))];
-}
-
-std::string decode_hex(std::string_view hex_string)
-{
-    if (hex_string.size() % 2 != 0) {
-        throw std::runtime_error{"Invalid wkb: Not a valid hex string"};
-    }
-
-    std::string wkb;
-    wkb.reserve(hex_string.size() / 2);
-
-    // NOLINTNEXTLINE(llvm-qualified-auto, readability-qualified-auto)
-    for (auto hex = hex_string.begin(); hex != hex_string.end();) {
-        unsigned int const c = decode_hex_char(*hex++);
-        wkb += static_cast<char>((c << 4U) | decode_hex_char(*hex++));
-    }
-
-    return wkb;
-}
