@@ -6,7 +6,7 @@
  *
  * This file is part of osm2pgsql (https://osm2pgsql.org/).
  *
- * Copyright (C) 2006-2024 by the osm2pgsql developer community.
+ * Copyright (C) 2006-2025 by the osm2pgsql developer community.
  * For a full list of authors see the git log.
  */
 
@@ -26,17 +26,27 @@ namespace testing::cleanup {
 class file_t
 {
 public:
-    file_t(std::string const &filename, bool remove_on_construct = true)
-    : m_filename(filename)
+    explicit file_t(std::string filename, bool remove_on_construct = true)
+    : m_filename(std::move(filename))
     {
         if (remove_on_construct) {
             delete_file(false);
         }
     }
 
+    file_t(file_t const &) = delete;
+    file_t &operator=(file_t const &) = delete;
+
+    file_t(file_t &&) = delete;
+    file_t &operator=(file_t const &&) = delete;
+
     ~file_t() noexcept { delete_file(true); }
 
 private:
+    // This function is run from a destructor so must be noexcept. If an
+    // exception does occur the program is terminated and we are fine with
+    // that, it is test code after all.
+    // NOLINTNEXTLINE(bugprone-exception-escape)
     void delete_file(bool warn) const noexcept
     {
         if (m_filename.empty()) {
