@@ -69,7 +69,7 @@ public:
     template <typename CONTAINER>
     explicit data_t(CONTAINER const &objects)
     {
-        std::copy(std::begin(objects), std::end(objects),
+        std::copy(std::cbegin(objects), std::cend(objects),
                   std::back_inserter(m_objects));
     }
 
@@ -78,13 +78,13 @@ public:
     template <typename CONTAINER>
     void add(CONTAINER const &objects)
     {
-        std::copy(std::begin(objects), std::end(objects),
+        std::copy(std::cbegin(objects), std::cend(objects),
                   std::back_inserter(m_objects));
     }
 
     void add(std::initializer_list<char const *> const &objects)
     {
-        std::copy(std::begin(objects), std::end(objects),
+        std::copy(std::cbegin(objects), std::cend(objects),
                   std::back_inserter(m_objects));
     }
 
@@ -111,7 +111,7 @@ private:
     static std::pair<osmium::item_type, osmium::object_id_type>
     get_type_id(std::string const &str)
     {
-        std::string ti(str, 0, str.find(' '));
+        std::string const ti(str, 0, str.find(' '));
         return osmium::string_to_object_id(ti.c_str(),
                                            osmium::osm_entity_bits::nwr);
     }
