@@ -23,27 +23,28 @@ namespace {
 
 testing::db::import_t db;
 
-char const *const data_file = "liechtenstein-2013-08-03.osm.pbf";
+char const *const DATA_FILE = "liechtenstein-2013-08-03.osm.pbf";
 
-} // anonymous namespace
-
-std::vector<std::string> get_files() {
+std::vector<std::string> get_files()
+{
     // NOLINTNEXTLINE(concurrency-mt-unsafe)
     char const *env = std::getenv("EXAMPLE_FILES");
     REQUIRE(env);
     return osmium::split_string(env, ',', true);
 }
 
+} // anonymous namespace
+
 TEST_CASE("minimal test for flex example configs")
 {
     auto const files = get_files();
 
-    for (auto const& file : files) {
+    for (auto const &file : files) {
         fmt::print(stderr, "Testing example config '{}.lua'\n", file);
         auto const conf_file = "../../flex-config/" + file + ".lua";
         options_t const options = testing::opt_t().flex(conf_file.c_str());
 
-        REQUIRE_NOTHROW(db.run_file(options, data_file));
+        REQUIRE_NOTHROW(db.run_file(options, DATA_FILE));
 
         auto conn = db.db().connect();
     }
