@@ -16,20 +16,20 @@ namespace {
 
 testing::db::import_t db;
 
-char const *const conf_file = "test_output_flex_schema.lua";
-char const *const data_file = "liechtenstein-2013-08-03.osm.pbf";
+char const *const CONF_FILE = "test_output_flex_schema.lua";
+char const *const DATA_FILE = "liechtenstein-2013-08-03.osm.pbf";
 
 } // anonymous namespace
 
 TEST_CASE("config with schema should work")
 {
-    options_t const options = testing::opt_t().slim().flex(conf_file);
+    options_t const options = testing::opt_t().slim().flex(CONF_FILE);
 
     auto conn = db.db().connect();
     conn.exec("CREATE SCHEMA IF NOT EXISTS myschema;");
     init_database_capabilities(conn);
 
-    REQUIRE_NOTHROW(db.run_file(options, data_file));
+    REQUIRE_NOTHROW(db.run_file(options, DATA_FILE));
 
     REQUIRE(1 ==
             conn.get_count("pg_catalog.pg_namespace", "nspname = 'myschema'"));
