@@ -16,7 +16,7 @@ namespace {
 
 testing::db::import_t db;
 
-char const *const conf_file = "test_output_flex_uni.lua";
+char const *const CONF_FILE = "test_output_flex_uni.lua";
 
 } // anonymous namespace
 
@@ -24,7 +24,7 @@ struct options_slim_default
 {
     static options_t options()
     {
-        return testing::opt_t().slim().flex(conf_file);
+        return testing::opt_t().slim().flex(CONF_FILE);
     }
 };
 
