@@ -17,7 +17,16 @@ namespace {
 
 testing::db::import_t db;
 
-char const *const conf_file = "test_output_flex.lua";
+char const *const CONF_FILE = "test_output_flex.lua";
+
+// Return a string with the schema name prepended to the table name.
+std::string with_schema(char const *table_name, options_t const &options)
+{
+    if (options.dbschema.empty()) {
+        return {table_name};
+    }
+    return options.dbschema + "." + table_name;
+}
 
 } // anonymous namespace
 
@@ -25,7 +34,7 @@ struct options_slim_default
 {
     static options_t options()
     {
-        return testing::opt_t().slim().flex(conf_file);
+        return testing::opt_t().slim().flex(CONF_FILE);
     }
 };
 
@@ -66,21 +75,12 @@ $$;
         conn.close();
         return testing::opt_t()
             .slim()
-            .flex(conf_file)
+            .flex(CONF_FILE)
             .schema("myschema")
             .user("limited", "password_limited");
     }
 };
 
-// Return a string with the schema name prepended to the table name.
-std::string with_schema(char const *table_name, options_t const &options)
-{
-    if (options.dbschema.empty()) {
-        return {table_name};
-    }
-    return options.dbschema + "." + table_name;
-}
-
 TEMPLATE_TEST_CASE("updating a node", "", options_slim_default,
                    options_slim_expire, options_slim_schema)
 {
